@@ -15,12 +15,22 @@ typedef struct Buffer_st
 	char *data;
 	} BUFFER;
 
-void buffer_clean_up();
+#ifdef PROTO
+void	buffer_clean_up(void);
+BUFFER *buffer_new(void);
+void	buffer_free(BUFFER *a);
+int	buffer_grow(BUFFER *str, long int len);
+int	buffer_get_tos(void);
+void	buffer_set_tos(int a);
+BUFFER *buffer_get_buf(void);
+#else
+void	buffer_clean_up();
 BUFFER *buffer_new();
-void buffer_free();
-int buffer_grow();
-int buffer_get_tos();
-void buffer_set_tos();
+void	buffer_free();
+int	buffer_grow();
+int	buffer_get_tos();
+void	buffer_set_tos();
 BUFFER *buffer_get_buf();
+#endif
 
 #endif
