@@ -7,16 +7,17 @@
  */
 
 #include <stdio.h>
-#include "PEM.h"
-#include "PEM_locl.h"
+#include "crypto.h"
 #include "der.h"
 #include "X509.h"
+#include "PEM.h"
+#include "PEM_locl.h"
 #include "Buffer.h"
 #include "des.h"
 #include "md2.h"
 #include "md5.h"
 
-static char *version="\0PEM part of SSLeay v 0.4.2 06/06/95";
+static char *version="\0PEM part of SSLeay v 0.4.3 15/06/95";
 
 #define MIN_LENGTH	4
 #define DES_COUNT	1
@@ -34,6 +35,16 @@ static char *version="\0PEM part of SSLeay v 0.4.2 06/06/95";
 #define CHUNKS_PER_LINE (64/4)
 #define CHAR_PER_LINE   (64+1)
 
+#ifdef PROTO
+static int PEM_bin2ascii(int len, unsigned char *f, unsigned char *t);
+static int PEM_ascii2bin(unsigned char *f, unsigned char *t);
+static void PEM_proc_type(char *buf, int type);
+static void PEM_dek_info(char *buf, int type, long int len, char *str);
+static void PEM_make_key_des_md5(int strl, char *str, int count, des_cblock (*iv), des_cblock (*key));
+static void PEM_make_key_des_md2(int strl, char *str, int count, des_cblock (*iv), des_cblock (*key));
+static int PEM_des_cbc_encrypt(unsigned char *input, unsigned char *output, long int length, struct des_ks_struct *ks, des_cblock (*iv), int encrypt);
+static int def_callback(char *buf, int num, int w);
+#else
 static int PEM_bin2ascii();
 static int PEM_ascii2bin();
 static void PEM_proc_type();
@@ -41,10 +52,10 @@ static void PEM_dek_info();
 static void PEM_make_key_des_md5();
 static void PEM_make_key_des_md2();
 static int PEM_des_cbc_encrypt();
-
 static int def_callback();
-static int (*callback)()=def_callback;
+#endif
 
+static int (*callback)()=def_callback;
 static unsigned char data_bin2ascii[65]="ABCDEFGHIJKLMNOPQRSTUVWXYZ\
 abcdefghijklmnopqrstuvwxyz0123456789+/";
 static unsigned char data_ascii2bin[256]={
@@ -66,10 +77,10 @@ static unsigned char data_ascii2bin[256]={
 	0x31,0x32,0x33,0xFF,0xFF,0xFF,0xFF,0xFF,
 	};
 
-
-static int def_callback(buf,num,w)
+static int def_callback(buf, num, w)
 char *buf;
-int num,w;
+int num;
+int w;
 	{
 	int i,j;
 
@@ -98,7 +109,7 @@ int (*a)();
 	callback=a;
 	}
 
-static void PEM_proc_type(buf,type)
+static void PEM_proc_type(buf, type)
 char *buf;
 int type;
 	{
@@ -118,10 +129,10 @@ int type;
 	strcat(buf,"\n");
 	}
 
-static void PEM_dek_info(buf,type,len,str)
+static void PEM_dek_info(buf, type, len, str)
 char *buf;
 int type;
-long len;
+long int len;
 char *str;
 	{
 	static unsigned char map[17]="0123456789ABCDEF";
@@ -155,12 +166,12 @@ char *str;
 	buf[j+i*2+1]='\0';
 	}
 
-int PEM_write_X509(fp,x)
+int PEM_write_X509(fp, x)
 FILE *fp;
 X509 *x;
 	{
 	int i;
-	char *buf,*p;
+	unsigned char *p,*buf;
 
 	i=i2D_X509(x,NULL);
 	if (i <= 0)
@@ -168,7 +179,7 @@ X509 *x;
 		PEM_errno=PEM_ERR_X509;
 		return(0);
 		}
-	buf=(char *)malloc(i);
+	buf=(unsigned char *)malloc(i);
 	if (buf == NULL)
 		{
 		PEM_errno=PEM_ERR_MALLOC_FAILURE;
@@ -181,13 +192,14 @@ X509 *x;
 	return(i);
 	}
 
-int PEM_read_X509(fp,x)
+int PEM_read_X509(fp, x)
 FILE *fp;
 X509 *x;
 	{
 	int i;
-	char *name,*header,*data;
-	int len;
+	char *name,*header;
+	unsigned char *data;
+	long len;
 
 	if (x == NULL)
 		{
@@ -221,14 +233,15 @@ X509 *x;
 	return(1);
 	}
 
-int PEM_read_RSA(fp,x)
+int PEM_read_RSA(fp, x)
 FILE *fp;
 RSA *x;
 	{
 	int i;
-	char *name,*header,*data;
+	char *name,*header;
+	unsigned char *data;
 	unsigned char *p;
-	int len;
+	long len;
 
 	if (x == NULL)
 		{
@@ -263,7 +276,7 @@ RSA *x;
 	return(1);
 	}
 
-int PEM_write_RSA(fp,r,enc,klen,kstr)
+int PEM_write_RSA(fp, r, enc, klen, kstr)
 FILE *fp;
 RSA *r;
 int enc;
@@ -305,16 +318,18 @@ char *kstr;
 		{
 		MD5_rand_seed(size,str); /**/
 		MD5_rand(8,iv);
-		PEM_make_key_des_md5(klen,pwd,DES_COUNT,&(iv[0]),&(key[0]));
+		PEM_make_key_des_md5(klen,pwd,DES_COUNT,
+			(des_cblock *)&(iv[0]),
+			(des_cblock *)&(key[0]));
 		if (pwd == buf) memset(buf,0,1024);
 		set_key((des_cblock *)&(key[0]),ks);
 
 		buff[0]='\0';
 		PEM_proc_type(buff,PEM_TYPE_ENCRYPTED);
-		PEM_dek_info(buff,PEM_DEK_DES_CBC,8,(unsigned char *)iv);
+		PEM_dek_info(buff,PEM_DEK_DES_CBC,8,(char *)iv);
 	
-		i=PEM_des_cbc_encrypt((C_Block *)str,(C_Block *)str,
-			size,ks,iv,DES_ENCRYPT);
+		i=PEM_des_cbc_encrypt(str,str,
+			size,ks,(C_Block *)&(iv[0]),DES_ENCRYPT);
 		}
 	else
 		buff[0]='\0';
@@ -329,10 +344,10 @@ char *kstr;
 	return(i);
 	}
 
-int PEM_do_header(header,len,data)
+int PEM_do_header(header, len, data)
 char *header;
 int len;
-char *data;
+unsigned char *data;
 	{
 	int i,v;
 	C_Block key,iv;
@@ -391,13 +406,14 @@ char *data;
 			PEM_errno=PEM_ERR_BAD_READ_PW_STRING;
 			return(0);
 			}
-		PEM_make_key_des_md5(strlen(buf),buf,DES_COUNT,&(iv[0]),
-			&(key[0]));
+		PEM_make_key_des_md5(strlen(buf),buf,DES_COUNT,
+			(C_Block *)&(iv[0]),
+			(C_Block *)&(key[0]));
 		memset(buf,0,1024);
 		set_key((des_cblock *)&(key[0]),ks);
 		memset(key,0,8);
-		i=PEM_des_cbc_encrypt((C_Block *)data,(C_Block *)data,
-			(long)len,ks,iv,DES_DECRYPT);
+		i=PEM_des_cbc_encrypt(data,data,
+			(long)len,ks,(C_Block *)&(iv[0]),DES_DECRYPT);
 		memset(iv,0,8);
 		memset(ks,0,sizeof(ks));
 		if (i == -1) return(0);
@@ -410,9 +426,10 @@ char *data;
 	return(1);
 	}
 
-static int PEM_bin2ascii(len,f,t)
+static int PEM_bin2ascii(len, f, t)
 int len;
-unsigned char *f,*t;
+unsigned char *f;
+unsigned char *t;
 	{
 	int r,i,j,chunks;
 	unsigned long l;
@@ -461,8 +478,9 @@ unsigned char *f,*t;
 	return(r);
 	}
 
-static int PEM_ascii2bin(f,t)
-unsigned char *f,*t;
+static int PEM_ascii2bin(f, t)
+unsigned char *f;
+unsigned char *t;
 	{
 	int i,j,chunks,err,c,sub;
 	unsigned long l,len;
@@ -518,22 +536,22 @@ unsigned char *f,*t;
 	return(len-sub);
 	}
 
-int PEM_write(fp,name,header,len,data)
+int PEM_write(fp, name, header, len, data)
 FILE *fp;
 char *name;
 char *header;
-long len;
-char *data;
+long int len;
+unsigned char *data;
 	{
 	int i;
-	char *buf;
+	unsigned char *buf;
 	
 	fprintf(fp,"-----BEGIN %s-----\n",name);
 	fputs(header,fp);
 	fputc('\n',fp);
 
 	i=PEM_bin2ascii(len,data,NULL);
-	buf=(char *)malloc(i+1);
+	buf=(unsigned char *)malloc(i+1);
 	if (buf == NULL) return(0);
 	i=PEM_bin2ascii(len,data,buf);
 	i=fwrite(buf,1,i,fp);
@@ -542,12 +560,12 @@ char *data;
 	return(i);
 	}
 
-int PEM_read(fp,name,header,len,data)
+int PEM_read(fp, name, header, len, data)
 FILE *fp;
 char **name;
 char **header;
-long *len;
-char **data;
+long int *len;
+unsigned char **data;
 	{
 	int end=0,i,j,hl;
 	char buf[256];
@@ -641,13 +659,14 @@ char **data;
 		goto err;
 		}
 
-	i=PEM_ascii2bin(dataB->data,dataB->data);
+	i=PEM_ascii2bin((unsigned char *)dataB->data,
+		(unsigned char *)dataB->data);
 	dataB->data[i]='\0';
 
 	if (i == 0) goto err;
 	*name=nameB->data;
 	*header=headerB->data;
-	*data=dataB->data;
+	*data=(unsigned char *)dataB->data;
 	*len=i;
 	free(nameB);
 	free(headerB);
@@ -661,19 +680,20 @@ err:
 	}
 
 /* pkcs-5 pbeWithMD5AndDESCBC { 1 2 840 113549 1 5 1 } */
-static void PEM_make_key_des_md5(strl,str,count,iv,key)
+static void PEM_make_key_des_md5(strl, str, count, iv, key)
 int strl;
 char *str;
 int count;
-C_Block *key,*iv;
+des_cblock (*iv);
+des_cblock (*key);
 	{
 	MD5_CTX c;
 	unsigned char md[MD5_DIGEST_LENGTH];
 	int i;
 
 	MD5Init(&c);
-	MD5Update(&c,str,strl);
-	MD5Update(&c,iv,8);
+	MD5Update(&c,(unsigned char *)str,strl);
+	MD5Update(&c,(unsigned char *)iv,8);
 	MD5Final(&(md[0]),&c);
 	for (i=1; i<count; i++)
 		MD5(MD5_DIGEST_LENGTH,&(md[0]),&(md[0]));
@@ -683,19 +703,20 @@ C_Block *key,*iv;
 	}
 
 /* pkcs-5 pbeWithMD2AndDESCBC { 1 2 840 113549 1 5 3 } */
-static void PEM_make_key_des_md2(strl,str,count,iv,key)
+static void PEM_make_key_des_md2(strl, str, count, iv, key)
 int strl;
 char *str;
 int count;
-C_Block *key,*iv;
+des_cblock (*iv);
+des_cblock (*key);
 	{
 	MD2_CTX c;
 	unsigned char md[MD2_DIGEST_LENGTH];
 	int i;
 
 	MD2Init(&c);
-	MD2Update(&c,str,strl);
-	MD2Update(&c,iv,8);
+	MD2Update(&c,(unsigned char *)str,strl);
+	MD2Update(&c,(unsigned char *)iv,8);
 	MD2Final(&(md[0]),&c);
 	for (i=1; i<count; i++)
 		MD2(MD5_DIGEST_LENGTH,&(md[0]),&(md[0]));
@@ -705,11 +726,12 @@ C_Block *key,*iv;
 	}
 
 /* must have room for padding of upto 8 bytes */
-static int PEM_des_cbc_encrypt(input,output,length,ks,iv,encrypt)
-unsigned char *input,*output;
-long length;
-des_key_schedule ks;
-des_cblock *iv;
+static int PEM_des_cbc_encrypt(input, output, length, ks, iv, encrypt)
+unsigned char *input;
+unsigned char *output;
+long int length;
+struct des_ks_struct *ks;
+des_cblock (*iv);
 int encrypt;
 	{
 	int i,v;
