@@ -29,12 +29,27 @@
 #define PEM_ERR_DER			18
 
 extern int PEM_errno;
-char *PEM_error_string();
 
-void PEM_set_getkey_callback();
-int PEM_write_X509();
-int PEM_read_X509();
-int PEM_read_RSA();
-int PEM_write_RSA();
+#ifdef PROTO
+char *	PEM_error_string(int n);
+int	PEM_do_header (char *header, int len, unsigned char *data);
+void	PEM_set_getkey_callback(int (*a) (/* ??? */));
+int	PEM_write_X509(FILE *fp, X509 *x);
+int	PEM_read (FILE *fp, char **name, char **header, long int *len, unsigned char **data);
+int	PEM_read_RSA(FILE *fp, RSA *x);
+int	PEM_read_X509(FILE *fp, X509 *x);
+int	PEM_write (FILE *fp, char *name, char *header, long int len, unsigned char *data);
+int	PEM_write_RSA(FILE *fp, RSA *r, int enc, int klen, char *kstr);
+#else
+char *	PEM_error_string();
+int	PEM_do_header ();
+void	PEM_set_getkey_callback();
+int	PEM_write_X509();
+int	PEM_read ();
+int	PEM_read_RSA();
+int	PEM_read_X509();
+int	PEM_write ();
+int	PEM_write_RSA();
+#endif
 
 #endif
