@@ -7,13 +7,15 @@
  */
 
 #include <stdio.h>
+#include "crypto.h"
 #include "der.h"
 #include "X509.h"
 
-static char *version="\0X509 part of SSLeay v 0.4.2 06/06/95";
+static char *version="\0X509 part of SSLeay v 0.4.3 15/06/95";
 
-int DER_OBJECT_eq(a,b)
-DER_OBJECT *a,*b;
+int DER_OBJECT_eq(a, b)
+DER_OBJECT *a;
+DER_OBJECT *b;
 	{
 	int i;
 
