@@ -7,13 +7,17 @@
  */
 
 #include <stdio.h>
+#include "crypto.h"
 #include "bn.h"
 #include "X509.h"
 
+#ifdef PROTO
+static void bn_SUB(BIGNUM *r, BIGNUM *a, BIGNUM *b);
+static void bn_fix_top(BIGNUM *a);
+#else
 static void bn_SUB();
-
-/*static BIGNUM *euclid(); */
 static void bn_fix_top();
+#endif
 
 int bn_num_bits(a)
 BIGNUM *a;
@@ -129,7 +133,7 @@ BIGNUM *bn_new()
 	return(ret);
 	}
 
-BIGNUM *bn_expand(b,bits)
+BIGNUM *bn_expand(b, bits)
 BIGNUM *b;
 int bits;
 	{
@@ -161,7 +165,7 @@ BIGNUM *a;
 	return((BIGNUM *)bn_copy(r,a));
 	}
 
-BIGNUM *bn_copy(a,b)
+BIGNUM *bn_copy(a, b)
 BIGNUM *a;
 BIGNUM *b;
 	{
@@ -203,7 +207,7 @@ BIGNUM *a;
 	}
 
 /* ignore negative */
-BIGNUM *bn_bin2bn(len,s,ret)
+BIGNUM *bn_bin2bn(len, s, ret)
 int len;
 unsigned char *s;
 BIGNUM *ret;
@@ -242,7 +246,7 @@ BIGNUM *ret;
 	return(ret);
 	}
 
-void bn_print(fp,a)
+void bn_print(fp, a)
 FILE *fp;
 BIGNUM *a;
 	{
@@ -261,7 +265,7 @@ BIGNUM *a;
 	}
 
 /* ignore negative */
-int bn_bn2bin(a,to)
+int bn_bn2bin(a, to)
 BIGNUM *a;
 unsigned char *to;
 	{
@@ -278,8 +282,10 @@ unsigned char *to;
 	}
 
 /* r can == a or b */
-int bn_add(r,a,b)
-BIGNUM *r,*a,*b;
+int bn_add(r, a, b)
+BIGNUM *r;
+BIGNUM *a;
+BIGNUM *b;
 	{
 	register int i;
 	int max,min;
@@ -357,8 +363,9 @@ BIGNUM *r,*a,*b;
 	return(1);
 	}
 
-int bn_Ucmp(a,b)
-BIGNUM *a,*b;
+int bn_Ucmp(a, b)
+BIGNUM *a;
+BIGNUM *b;
 	{
 	int i;
 	BN_ULONG t1,t2,*ap,*bp;
@@ -377,8 +384,9 @@ BIGNUM *a,*b;
 	return(0);
 	}
 
-int bn_cmp(a,b)
-BIGNUM *a,*b;
+int bn_cmp(a, b)
+BIGNUM *a;
+BIGNUM *b;
 	{
 	int i;
 	int gt,lt;
@@ -406,8 +414,10 @@ BIGNUM *a,*b;
 	return(0);
 	}
 
-static void bn_SUB(r,a,b)
-BIGNUM *r,*a,*b;
+static void bn_SUB(r, a, b)
+BIGNUM *r;
+BIGNUM *a;
+BIGNUM *b;
 	{
 	int max,min;
 	register BN_ULONG t1,t2,*ap,*bp,*rp;
@@ -460,8 +470,10 @@ BIGNUM *r,*a,*b;
 	bn_fix_top(r);
 	}
 
-int bn_sub(r,a,b)
-BIGNUM *r,*a,*b;
+int bn_sub(r, a, b)
+BIGNUM *r;
+BIGNUM *a;
+BIGNUM *b;
 	{
 	int max,i;
 
@@ -624,8 +636,10 @@ BIGNUM *r,*a,*b;
 #endif
 
 /* r must be different to a and b */
-int bn_mul(r,a,b)
-BIGNUM *r,*a,*b;
+int bn_mul(r, a, b)
+BIGNUM *r;
+BIGNUM *a;
+BIGNUM *b;
 	{
 	register int i,j;
 	int max;
@@ -685,6 +699,15 @@ BIGNUM *r,*a,*b;
 			if (l2 < l) c1++;
 			c2=(c1 < h)?1:0;
 			}
+		/* As was pointed out by Paul Riethmuller <par@sequent.com>
+		 * the following is not needed because I am 'working'
+		 * my way 'up' the words.  I suppose I just got
+		 * carried away when I wrote the code orignally, or was
+		 * it just because I was paranoid about covering all
+		 * posibilities :-) */
+		*rp = c1;
+
+#ifdef undef
 		if (c1 | c2)
 			{
 			for (;;)
@@ -704,13 +727,15 @@ BIGNUM *r,*a,*b;
 				if ((c1|c2) == 0) break;
 				}
 			}
+#endif
 		}
 	bn_fix_top(r);
 	return(1);
 	}
 
-int bn_lshift1(r,a)
-BIGNUM *r,*a;
+int bn_lshift1(r, a)
+BIGNUM *r;
+BIGNUM *a;
 	{
 	register BN_ULONG *ap,*rp,t,c;
 	int i;
@@ -742,8 +767,9 @@ BIGNUM *r,*a;
 	return(1);
 	}
 
-int bn_rshift1(r,a)
-BIGNUM *r,*a;
+int bn_rshift1(r, a)
+BIGNUM *r;
+BIGNUM *a;
 	{
 	BN_ULONG *ap,*rp,t,c;
 	int i;
@@ -772,8 +798,9 @@ BIGNUM *r,*a;
 	return(1);
 	}
 
-int bn_lshift(r,a,n)
-BIGNUM *r,*a;
+int bn_lshift(r, a, n)
+BIGNUM *r;
+BIGNUM *a;
 int n;
 	{
 	int i,nw,lb,rb;
@@ -805,8 +832,9 @@ int n;
 	return(1);
 	}
 
-int bn_rshift(r,a,n)
-BIGNUM *r,*a;
+int bn_rshift(r, a, n)
+BIGNUM *r;
+BIGNUM *a;
 int n;
 	{
 	int i,nw,lb,rb;
@@ -930,8 +958,9 @@ BIGNUM *a,*b;
 	}
 #endif
 
-int bn_clear_bit(a,n)
+int bn_clear_bit(a, n)
 BIGNUM *a;
+int n;
 	{
 	int i,j;
 
@@ -942,8 +971,9 @@ BIGNUM *a;
 	return(a->d[i]&(~(1L<<j)));
 	}
 
-int bn_is_bit_set(a,n)
+int bn_is_bit_set(a, n)
 BIGNUM *a;
+int n;
 	{
 	int i,j;
 
@@ -954,8 +984,10 @@ BIGNUM *a;
 	}
 
 /* rem != m */
-int bn_mod(rem,m,d)
-BIGNUM *rem,*m,*d;
+int bn_mod(rem, m, d)
+BIGNUM *rem;
+BIGNUM *m;
+BIGNUM *d;
 	{
 	int i,nm,nd,tos;
 	BIGNUM *div;
@@ -1029,7 +1061,7 @@ static BIGNUM *mod_shifts[BITS2];
 static BN_ULONG *mod_shiftp[BITS2];
 static int mod_top[BITS2];
 
-int bn_MOD_init(d,max_bits)
+int bn_MOD_init(d, max_bits)
 BIGNUM *d;
 int max_bits;
 	{
@@ -1063,8 +1095,10 @@ int max_bits;
 	return(1);
 	}
 
-int bn_MOD(ret,m,d)
-BIGNUM *ret,*m,*d;
+int bn_MOD(ret, m, d)
+BIGNUM *ret;
+BIGNUM *m;
+BIGNUM *d;
 	{
 	int i,j,nm,nd,x;
 	int w;
@@ -1107,8 +1141,11 @@ BIGNUM *ret,*m,*d;
 	return(1);
 	}
 
-int bn_div(div,rem,m,d)
-BIGNUM *div,*rem,*m,*d;
+int bn_div(div, rem, m, d)
+BIGNUM *div;
+BIGNUM *rem;
+BIGNUM *m;
+BIGNUM *d;
 	{
 	int i,nm,nd;
 	BIGNUM *D;
@@ -1165,80 +1202,80 @@ BIGNUM *div,*rem,*m,*d;
 #ifdef undef
 void bn_mul0(r,a,b)
 BIGNUM *r,*a,*b;
-        {
-        int i,j,k,max,nr,na,nb,mask;
-        BIGNUM *tmp;
-        static int init=1;
-        static BIGNUM *shifts[BITS2];
-        BN_ULONG *shiftp[BITS2];
-        BN_ULLONG l;
+   {
+   int i,j,k,max,nr,na,nb,mask;
+   BIGNUM *tmp;
+   static int init=1;
+   static BIGNUM *shifts[BITS2];
+   BN_ULONG *shiftp[BITS2];
+   BN_ULLONG l;
 	BN_ULONG *rp,*ap,*bp,*sp;
 
-        if (bn_cmp(a,b) < 0)
-                {
-                tmp=a;
-                a=b;
-                b=tmp;
-                }
+   if (bn_cmp(a,b) < 0)
+           {
+           tmp=a;
+           a=b;
+           b=tmp;
+           }
 
-        if (init)
-                {
-                init=0;
-                for (i=0; i<BITS; i++)
-                        {
-                        shifts[i]=bn_new();
-                        }
-                }
+   if (init)
+           {
+           init=0;
+           for (i=0; i<BITS; i++)
+                   {
+                   shifts[i]=bn_new();
+                   }
+           }
 
-        max=(a->top+b->top+1);
-        bn_expand(r,(max+1)*BITS2);
-        bn_zero(r);
+   max=(a->top+b->top+1);
+   bn_expand(r,(max+1)*BITS2);
+   bn_zero(r);
 
-        na=bn_num_bits(a);
-        nb=bn_num_bits(b);
-        bn_copy(shifts[0],a);
-        for (i=1; i<BITS2; i++) bn_lshift1(shifts[i],shifts[i-1]);
-        for (i=0; i<BITS2; i++) shiftp[i]=shifts[i]->d;
+   na=bn_num_bits(a);
+   nb=bn_num_bits(b);
+   bn_copy(shifts[0],a);
+   for (i=1; i<BITS2; i++) bn_lshift1(shifts[i],shifts[i-1]);
+   for (i=0; i<BITS2; i++) shiftp[i]=shifts[i]->d;
 	ap=a->d;
 	bp=b->d;
 	rp=r->d;
 
-        mask=1;
-        for (i=0; i<BITS2; i++)
-                {
-                for (j=0; j<b->top; j++)
-                        {
-                        if (bp[j]&mask)
-                                {
+   mask=1;
+   for (i=0; i<BITS2; i++)
+           {
+           for (j=0; j<b->top; j++)
+                   {
+                   if (bp[j]&mask)
+                           {
 				sp=shifts[i]->d;
-                                for (k=0; k<shifts[i]->top; k++)
-                                        rp[j+k]+=sp[k];
-                                }
-                        }
+                           for (k=0; k<shifts[i]->top; k++)
+                                   rp[j+k]+=sp[k];
+                           }
+                   }
 		mask<<=1;
-                }
+           }
 
-        for (i=0; i<max; i++)
-                {
+   for (i=0; i<max; i++)
+           {
 		l=rp[i];
-                if (l > MASK2)
-                        {
-                        rp[i+1]+=(l>>BITS2);
-                        rp[i]=l&MASK2;
-                        rp[i]=l&MASK2;
-                        }
-                }
-        while ((rp[max] == 0) && (max > 0))
-                max--;
-        r->top=max+1;
-        r->numbits=r->top*BITS2;
+           if (l > MASK2)
+                   {
+                   rp[i+1]+=(l>>BITS2);
+                   rp[i]=l&MASK2;
+                   rp[i]=l&MASK2;
+                   }
+           }
+   while ((rp[max] == 0) && (max > 0))
+           max--;
+   r->top=max+1;
+   r->numbits=r->top*BITS2;
 	r->neg=a->neg^b->neg;
 	}
 #endif
 
-BN_ULONG bn_mod_word(a,w)
+BN_ULONG bn_mod_word(a, w)
 BIGNUM *a;
-BN_ULONG w;
+unsigned long w;
 	{
 	BN_ULONG ret;
 	int i;
@@ -1256,9 +1293,9 @@ BN_ULONG w;
 	return(ret);
 	}
 
-int bn_add_word(a,w)
+int bn_add_word(a, w)
 BIGNUM *a;
-BN_ULONG w;
+unsigned long w;
 	{
 	BN_ULONG l;
 	int i;
@@ -1281,8 +1318,11 @@ BN_ULONG w;
 	}
 
 
-int bn_mul_mod(ret,a,b,m)
-BIGNUM *ret,*a,*b,*m;
+int bn_mul_mod(ret, a, b, m)
+BIGNUM *ret;
+BIGNUM *a;
+BIGNUM *b;
+BIGNUM *m;
 	{
 	BIGNUM *t;
 	int tos,r=1;
@@ -1335,8 +1375,11 @@ err:
 	}
 
 #else
-int bn_mod_exp(r,a,p,m)
-BIGNUM *r,*a,*p,*m;
+int bn_mod_exp(r, a, p, m)
+BIGNUM *r;
+BIGNUM *a;
+BIGNUM *p;
+BIGNUM *m;
 	{
 	int tos,nb,i,bits;
 	BIGNUM *v=NULL,*tmp=NULL;
@@ -1441,8 +1484,12 @@ BIGNUM *r,*a,*p,*m;
 	}
 #endif
 
-int bn_modmul_recip(r,x,y,m,i,nb)
-BIGNUM *r,*x,*y,*m,*i;
+int bn_modmul_recip(r, x, y, m, i, nb)
+BIGNUM *r;
+BIGNUM *x;
+BIGNUM *y;
+BIGNUM *m;
+BIGNUM *i;
 int nb;
 	{
 	int tos,j;
@@ -1480,8 +1527,9 @@ err:
 	return(0);
 	}
 
-int bn_reciprical(r,m)
-BIGNUM *r,*m;
+int bn_reciprical(r, m)
+BIGNUM *r;
+BIGNUM *m;
 	{
 	int nm,tos;
 	BIGNUM *t;
