@@ -7,19 +7,27 @@
  */
 
 #include <stdio.h>
-#include "X509.h"
+#include "crypto.h"
 #include "der.h"
+#include "X509.h"
 
-static char *version="\0DER part of SSLeay v 0.4.2 06/06/95";
+static char *version="\0DER part of SSLeay v 0.4.3 15/06/95";
 
+#ifdef PROTO
+static unsigned long der_get_length(unsigned char **pp);
+static void der_put_length(unsigned char **pp, int length);
+static void der_print_info(FILE *file, int tag, int class);
+#else
 static unsigned long der_get_length();
 static void der_put_length();
 static void der_print_info();
+#endif
 
-int DER_get_object(pp,plength,ptag,pclass)
+int DER_get_object(pp, plength, ptag, pclass)
 unsigned char **pp;
 unsigned long *plength;
-int *ptag,*pclass;
+int *ptag;
+int *pclass;
 	{
 	int i,ret;
 	unsigned long l;
@@ -55,9 +63,10 @@ int *ptag,*pclass;
 	}
 
 
-int DER_object_size(constructed,length,tag)
+int DER_object_size(constructed, length, tag)
 int constructed;
-int length,tag;
+int length;
+int tag;
 	{
 	int ret;
 
@@ -86,10 +95,12 @@ int length,tag;
 	}
 
 /* class 0 is constructed */
-void DER_put_object(pp,constructed,length,tag,class)
+void DER_put_object(pp, constructed, length, tag, class)
 unsigned char **pp;
 int constructed;
-int length,tag,class;
+int length;
+int tag;
+int class;
 	{
 	unsigned char *p= *pp;
 	int i;
@@ -115,7 +126,7 @@ int length,tag,class;
 	*pp=p;
 	}
 
-static void der_put_length(pp,length)
+static void der_put_length(pp, length)
 unsigned char **pp;
 int length;
 	{
@@ -162,7 +173,7 @@ unsigned char **pp;
 	return(ret);
 	}
 
-int i2D_DER_BIT_STRING(a,pp)
+int i2D_DER_BIT_STRING(a, pp)
 DER_BIT_STRING *a;
 unsigned char **pp;
 	{
@@ -172,11 +183,11 @@ unsigned char **pp;
 	/* our bit strings are always a multiple of 8 :-) */
 	bits=0;
 	ret=1+a->length;
-	r=DER_object_size(0,ret,DER_DER_BIT_STRING);
+	r=DER_object_size(0,ret,DER_BIT_STRING_IDENTIFIER);
 	if (pp == NULL) return(r);
 	p= *pp;
 
-	DER_put_object(&p,0,ret,DER_DER_BIT_STRING,DER_UNIVERSAL);
+	DER_put_object(&p,0,ret,DER_BIT_STRING_IDENTIFIER,DER_UNIVERSAL);
 	if (bits == 0)
 		j=0;
 	else	j=8-bits;
@@ -188,7 +199,7 @@ unsigned char **pp;
 	return(r);
 	}
 
-int i2D_OCTET_STRING(a,pp)
+int i2D_OCTET_STRING(a, pp)
 DER_BIT_STRING *a;
 unsigned char **pp;
 	{
@@ -207,14 +218,14 @@ unsigned char **pp;
 	return(r);
 	}
 
-int i2D_UTCTime(a,pp)
-unsigned char *a;
+int i2D_UTCTime(a, pp)
+char *a;
 unsigned char **pp;
 	{
 	int ret,r;
 	unsigned char *p;
 
-	ret=strlen(a);
+	ret=strlen((char *)a);
 	r=DER_object_size(0,ret,DER_UTCTIME);
 	if (pp == NULL) return(r);
 	p= *pp;
@@ -226,7 +237,7 @@ unsigned char **pp;
 	return(r);
 	}
 
-int i2D_DER_OBJECT(a,pp)
+int i2D_DER_OBJECT(a, pp)
 DER_OBJECT *a;
 unsigned char **pp;
 	{
@@ -244,11 +255,11 @@ unsigned char **pp;
 			l>>=7;
 			} while (l);
 		}
-	r=DER_object_size(0,ret,DER_DER_OBJECT_IDENTIFIER);
+	r=DER_object_size(0,ret,DER_OBJECT_IDENTIFIER);
 	if (pp == NULL) return(r);
 
 	p= *pp;
-	DER_put_object(&p,0,ret,DER_DER_OBJECT_IDENTIFIER,DER_UNIVERSAL);
+	DER_put_object(&p,0,ret,DER_OBJECT_IDENTIFIER,DER_UNIVERSAL);
 
 	if (a->num == 0)
 		*(p++)=(unsigned char)(a->values[0]*40);
@@ -282,7 +293,7 @@ unsigned char **pp;
 	return(r);
 	}
 
-int i2D_INTEGER(a,pp)
+int i2D_INTEGER(a, pp)
 DER_BIT_STRING *a;
 unsigned char **pp;
 	{
@@ -306,7 +317,7 @@ unsigned char **pp;
 	return(r);
 	}
 
-void i2f_DER_BIT_STRING(fp,a)
+void i2f_DER_BIT_STRING(fp, a)
 FILE *fp;
 DER_BIT_STRING *a;
 	{
@@ -334,7 +345,7 @@ DER_BIT_STRING *a;
 	fprintf(fp,"\n");
 	}
 
-void i2f_DER_OBJECT(fp,a)
+void i2f_DER_OBJECT(fp, a)
 FILE *fp;
 DER_OBJECT *a;
 	{
@@ -370,7 +381,7 @@ unsigned long *d;
 	}
 #endif
 
-int D2i_INTEGER(bs,pp)
+int D2i_INTEGER(bs, pp)
 DER_BIT_STRING *bs;
 unsigned char **pp;
 	{
@@ -406,36 +417,7 @@ unsigned char **pp;
 	return(1);
 	}
 
-#ifdef undef
-int D2i_BN_INTEGER(max,d,pp)
-int max;
-unsigned char *d;
-unsigned char **pp;
-	{
-	unsigned char *p;
-	unsigned long len;
-	int tag,class;
-
-	p= *pp;
-	DER_get_object(&p,&len,&tag,&class);
-#ifdef DER_DEBUG
-	fprintf(stderr,"D2i_INTEGER len=%d ",len);
-	der_print_info(stderr,tag,class);
-#endif
-	if (tag != DER_INTEGER)
-		{
-		fprintf(stderr,"expecting an INTEGER in D2i_INTEGER\n");
-		exit(1);
-		}
-	if (max > len) max=len;
-	memcpy(d,p,max);
-	p+=len;
-	*pp=p;
-	return(max);
-	}
-#endif
-
-int D2i_DER_OBJECT(o,pp)
+int D2i_DER_OBJECT(o, pp)
 DER_OBJECT *o;
 unsigned char **pp;
 	{
@@ -446,7 +428,7 @@ unsigned char **pp;
 
 	p= *pp;
 	DER_get_object(&p,&len,&tag,&class);
-	if (tag != DER_DER_OBJECT_IDENTIFIER)
+	if (tag != DER_OBJECT_IDENTIFIER)
 		{
 		DER_errno=DER_ERR_EXPECTING_AN_OBJECT_IDENTIFIER_IN_D2I_DER_OBJECT;
 		return(0);
@@ -482,7 +464,7 @@ unsigned char **pp;
 	return(1);
 	}
 
-int D2i_PRINTABLESTRING(sp,pp)
+int D2i_PRINTABLESTRING(sp, pp)
 unsigned char **sp;
 unsigned char **pp;
 	{
@@ -513,7 +495,7 @@ unsigned char **pp;
 	return(1);
 	}
 
-D2i_DER_BIT_STRING(bp,pp)
+D2i_DER_BIT_STRING(bp, pp)
 DER_BIT_STRING *bp;
 unsigned char **pp;
 	{
@@ -524,7 +506,7 @@ unsigned char **pp;
 
 	p= *pp;
 	DER_get_object(&p,&len,&tag,&class);
-	if (tag != DER_DER_BIT_STRING)
+	if (tag != DER_BIT_STRING_IDENTIFIER)
 		{
 		DER_errno=DER_ERR_EXPECTING_A_DER_BIT_STRING_IN_D2i_DER_BIT_STRING;
 		return(0);
@@ -552,7 +534,7 @@ unsigned char **pp;
 	return(1);
 	}
 
-int D2i_OCTET_STRING(bp,pp)
+int D2i_OCTET_STRING(bp, pp)
 DER_BIT_STRING *bp;
 unsigned char **pp;
 	{
@@ -588,7 +570,7 @@ unsigned char **pp;
 	return(1);
 	}
 
-int D2i_UTCTime(sp,pp)
+int D2i_UTCTime(sp, pp)
 unsigned char **sp;
 unsigned char **pp;
 	{
@@ -619,82 +601,124 @@ unsigned char **pp;
 	return(1);
 	}
 
-static void der_print_info(file,tag,class)
+static void der_print_info(file, tag, class)
 FILE *file;
-int tag,class;
+int tag;
+int class;
 	{
+	static char *fmt="%-18s";
+
 	if (class & DER_CONSTRUCTED)
-		fprintf(file,"construct: ");
+		fprintf(file,"cons: ");
 	else
-		fprintf(file,"primative: ");
+		fprintf(file,"prim: ");
 	if ((class & DER_PRIVATE) == DER_PRIVATE)
-		fprintf(file,"private   : ");
+		fprintf(file,"priv: ");
 	else if ((class & DER_CONTEXT_SPECIFIC) == DER_CONTEXT_SPECIFIC)
-		fprintf(file,"context   : ");
+		fprintf(file,"cont: ");
 	else if ((class & DER_APPLICATION) == DER_APPLICATION)
-		fprintf(file,"applicaion: ");
+		fprintf(file,"appl: ");
 	else if ((class & DER_UNIVERSAL) == DER_UNIVERSAL) /* lint complains */
-		fprintf(file,"universal : ");
+		fprintf(file,"univ: ");
 
 	if (tag == DER_EOC)
-		fprintf(file,"EOC");
+		fprintf(file,fmt,"EOC");
 	else if (tag == DER_INTEGER)
-		fprintf(file,"INTEGER");
-	else if (tag == DER_DER_BIT_STRING)
-		fprintf(file,"DER_BIT_STRING");
+		fprintf(file,fmt,"INTEGER");
+	else if (tag == DER_BIT_STRING_IDENTIFIER)
+		fprintf(file,fmt,"DER_BIT_STRING");
 	else if (tag == DER_OCTET_STRING)
-		fprintf(file,"OCTET_STRING");
+		fprintf(file,fmt,"OCTET_STRING");
 	else if (tag == DER_NULL)
-		fprintf(file,"NULL");
-	else if (tag == DER_DER_OBJECT_IDENTIFIER)
-		fprintf(file,"DER_OBJECT_IDENTIFIER");
+		fprintf(file,fmt,"NULL");
+	else if (tag == DER_OBJECT_IDENTIFIER)
+		fprintf(file,fmt,"OBJECT_IDENTIFIER");
 	else if (tag == DER_SEQUENCE)
-		fprintf(file,"SEQUENCE");
+		fprintf(file,fmt,"SEQUENCE");
 	else if (tag == DER_SET)
-		fprintf(file,"SET");
+		fprintf(file,fmt,"SET");
 	else if (tag == DER_PRINTABLESTRING)
-		fprintf(file,"PRINTABLESTRING");
+		fprintf(file,fmt,"PRINTABLESTRING");
 	else if (tag == DER_T61STRING)
-		fprintf(file,"T61STRING");
+		fprintf(file,fmt,"T61STRING");
 	else if (tag == DER_IA5STRING)
-		fprintf(file,"IA5STRING");
+		fprintf(file,fmt,"IA5STRING");
 	else if (tag == DER_UTCTIME)
-		fprintf(file,"UTCTIME");
-	else	fprintf(file,"unknown");
-	fprintf(file,"\n");
+		fprintf(file,fmt,"UTCTIME");
+	else	fprintf(file,fmt,"unknown");
 	}
 
 static void der_parse2();
 
-void DER_parse(fp,pp)
+void DER_parse(fp, pp, len)
 FILE *fp;
 unsigned char *pp;
+int len;
 	{
-	der_parse2(fp,&pp,0);
+	der_parse2(fp,&pp,len,0,0);
 	}
 
-static void der_parse2(fp,pp,depth)
+static void der_parse2(fp, pp, length, offset, depth)
 FILE *fp;
 unsigned char **pp;
+int length;
+int offset;
 int depth;
 	{
-	unsigned char *p,*ep;
+	unsigned char *p,*ep,*tot,*op;
 	unsigned long len;
 	int tag,class;
-	int i;
+	int nl,i;
 
 	p= *pp;
-	DER_get_object(&p,&len,&tag,&class);
-	for (i=0; i<depth; i++) fputc(' ',fp);
-	fprintf(fp,"depth=%d len=%3d ",depth,len);
-	der_print_info(fp,tag,class);
-	if (class & DER_CONSTRUCTED)
+	tot=p+length;
+	while (p < tot)
 		{
-		ep=p+len;
-		while (p < ep)
-			der_parse2(fp,&p,depth+1);
+		op=p;
+		DER_get_object(&p,&len,&tag,&class);
+		fprintf(fp,"%5d:",offset+op- *pp);
+		fprintf(fp,"d=%d l=%3d ",depth,len);
+		der_print_info(fp,tag,class);
+		if (class & DER_CONSTRUCTED)
+			{
+			ep=p+len;
+			fputc('\n',fp);
+			while (p < ep)
+				der_parse2(fp,&p,len,offset+(p - *pp),depth+1);
+			}
+		else
+			{
+			nl=0;
+			if (	(tag == DER_PRINTABLESTRING) ||
+				(tag == DER_T61STRING) ||
+				(tag == DER_IA5STRING) ||
+				(tag == DER_UTCTIME))
+				{
+				fputc(':',fp);
+				for (i=0; i<len; i++)
+					fputc(p[i],fp);
+				}
+			if (tag == DER_OBJECT_IDENTIFIER)
+				{
+				DER_OBJECT *o;
+				char *s;
+
+				o=DER_OBJECT_new();
+				i=D2i_DER_OBJECT(o,&op);
+				s=(char *)X509_nid2ln(X509_obj2nid(o));
+				if (s == NULL)
+					{
+					i2f_DER_OBJECT(fp,o);
+					DER_OBJECT_free(o);
+					nl=1;
+					}
+				else
+					fprintf(fp,":%s",
+						X509_nid2ln(X509_obj2nid(o)));
+				}
+			if (!nl) fputc('\n',fp);
+			p+=len;
+			}
 		}
-	else
-		p+=len;
 	*pp=p;
 	}
