@@ -7,9 +7,11 @@
  */
 
 #include <stdio.h>
-#include "des_locl.h" /* for des.h and bcopy macros */
-/* tisk tisk - the test keys don't all have odd parity :-( */
+#include <stdlib.h>
+#include <string.h>
+#include "des.h"
 
+/* tisk tisk - the test keys don't all have odd parity :-( */
 /* test data */
 #define NUM_TESTS 34
 static unsigned char key_data[NUM_TESTS][8]={
@@ -160,7 +162,7 @@ static unsigned char cbc_key [8]={0x01,0x23,0x45,0x67,0x89,0xab,0xcd,0xef};
 static unsigned char cbc3_key[8]={0xf0,0xe1,0xd2,0xc3,0xb4,0xa5,0x96,0x87};
 static unsigned char cbc_iv  [8]={0xfe,0xdc,0xba,0x98,0x76,0x54,0x32,0x10};
 static unsigned char cbc3_iv [8]={0x0f,0x1e,0x2d,0x3c,0x4b,0x5a,0x69,0x78};
-static unsigned char cbc_data[40]="7654321 Now is the time for ";
+static char cbc_data[40]="7654321 Now is the time for ";
 
 static unsigned char cbc_ok[32]={
 	0xcc,0xd1,0x73,0xff,0xab,0x20,0x39,0xf4,
@@ -222,17 +224,22 @@ static unsigned char ofb_cipher[24]=
 unsigned long cbc_cksum_ret=0xB462FEF7;
 unsigned char cbc_cksum_data[8]={0x1D,0x26,0x93,0x97,0xf7,0xfe,0x62,0xb4};
 
-char *malloc();
-char *pt();
-int cfb_test();
-int cfb64_test();
+#ifdef PROTO
+static char *pt(unsigned char *p);
+static int cfb_test(int bits, unsigned char *cfb_cipher);
+static int cfb64_test(int bits, unsigned char *cfb_cipher);
+#else
+static char *pt();
+static int cfb_test();
+static int cfb64_test();
+#endif
 
 main()
 	{
 	int i,j,err=0;
 	des_cblock in,out,outin,iv3a,iv3b;
 	des_key_schedule ks,ks2;
-	unsigned char cbc_in[40],cbc_out[40];
+	char cbc_in[40],cbc_out[40];
 	unsigned long cs;
 	unsigned char qret[4][4],cret[8];
 	unsigned long lqret[4];
@@ -247,20 +254,20 @@ main()
 			printf("Key error %2d:%d\n",i+1,j);
 			err=1;
 			}
-		bcopy(plain_data[i],in,8);
-		bzero(out,8);
-		bzero(outin,8);
+		memcpy(in,plain_data[i],8);
+		memset(out,0,8);
+		memset(outin,0,8);
 		des_ecb_encrypt((C_Block *)in,(C_Block *)out,ks,DES_ENCRYPT);
 		des_ecb_encrypt((C_Block *)out,(C_Block *)outin,ks,DES_DECRYPT);
 
-		if (bcmp(out,cipher_data[i],8) != 0)
+		if (memcmp(out,cipher_data[i],8) != 0)
 			{
 			printf("Encryption error %2d\nk=%s p=%s o=%s act=%s\n",
 				i+1,pt(key_data[i]),pt(in),pt(cipher_data[i]),
 				pt(out));
 			err=1;
 			}
-		if (bcmp(in,outin,8) != 0)
+		if (memcmp(in,outin,8) != 0)
 			{
 			printf("Decryption error %2d\nk=%s p=%s o=%s act=%s\n",
 				i+1,pt(key_data[i]),pt(out),pt(in),pt(outin));
@@ -281,22 +288,22 @@ main()
 			printf("Key error %2d:%d\n",i+2,j);
 			err=1;
 			}
-		bcopy(plain_data[i],in,8);
-		bzero(out,8);
-		bzero(outin,8);
+		memcpy(in,plain_data[i],8);
+		memset(out,0,8);
+		memset(outin,0,8);
 		des_3ecb_encrypt((C_Block *)in,(C_Block *)out,ks,ks2,
 			DES_ENCRYPT);
 		des_3ecb_encrypt((C_Block *)out,(C_Block *)outin,ks,ks2,
 			DES_DECRYPT);
 
-		if (bcmp(out,cipher_3ecb[i],8) != 0)
+		if (memcmp(out,cipher_3ecb[i],8) != 0)
 			{
 			printf("Encryption error %2d\nk=%s p=%s o=%s act=%s\n",
 				i+1,pt(key_data[i]),pt(in),pt(cipher_3ecb[i]),
 				pt(out));
 			err=1;
 			}
-		if (bcmp(in,outin,8) != 0)
+		if (memcmp(in,outin,8) != 0)
 			{
 			printf("Decryption error %2d\nk=%s p=%s o=%s act=%s\n",
 				i+1,pt(key_data[i]),pt(out),pt(in),pt(outin));
@@ -310,15 +317,17 @@ main()
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	bzero(cbc_out,40);
-	bzero(cbc_in,40);
+	memset(cbc_out,0,40);
+	memset(cbc_in,0,40);
 	des_cbc_encrypt((C_Block *)cbc_data,(C_Block *)cbc_out,
-		(long)strlen(cbc_data)+1,ks,(C_Block *)cbc_iv,DES_ENCRYPT);
-	if (bcmp(cbc_out,cbc_ok,32) != 0)
+		(long)strlen((char *)cbc_data)+1,ks,
+		(C_Block *)cbc_iv,DES_ENCRYPT);
+	if (memcmp(cbc_out,cbc_ok,32) != 0)
 		printf("cbc_encrypt encrypt error\n");
 	des_cbc_encrypt((C_Block *)cbc_out,(C_Block *)cbc_in,
-		(long)strlen(cbc_data)+1,ks,(C_Block *)cbc_iv,DES_DECRYPT);
-	if (bcmp(cbc_in,cbc_data,32) != 0)
+		(long)strlen((char *)cbc_data)+1,ks,
+		(C_Block *)cbc_iv,DES_DECRYPT);
+	if (memcmp(cbc_in,cbc_data,32) != 0)
 		{
 		printf("cbc_encrypt decrypt error\n");
 		err=1;
@@ -335,11 +344,11 @@ main()
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	bcopy(cbc_iv,iv3a,sizeof(cbc_iv));
-	bcopy(cbc3_iv,iv3b,sizeof(cbc_iv));
-	bzero(cbc_out,40);
-	bzero(cbc_in,40);
-	i=strlen(cbc_data)+1;
+	memcpy(iv3a,cbc_iv,sizeof(cbc_iv));
+	memcpy(iv3b,cbc3_iv,sizeof(cbc_iv));
+	memset(cbc_out,0,40);
+	memset(cbc_in,0,40);
+	i=strlen((char *)cbc_data)+1;
 	i=((i+7)/8)*8;
 	des_3cbc_encrypt((C_Block *)cbc_data,(C_Block *)cbc_out,
 		16,ks,ks2,(C_Block *)iv3a,
@@ -347,18 +356,18 @@ main()
 	des_3cbc_encrypt((C_Block *)&(cbc_data[16]),(C_Block *)&(cbc_out[16]),
 		(long)i-16,ks,ks2,(C_Block *)iv3a,
 		(C_Block *)iv3b,DES_ENCRYPT);
-	if (bcmp(cbc_out,cbc3_ok,(strlen(cbc_data)+1+7)/8*8) != 0)
+	if (memcmp(cbc_out,cbc3_ok,(int)(strlen((char *)cbc_data)+1+7)/8*8) != 0)
 		{
 		printf("des_3cbc_encrypt encrypt error\n");
 		err=1;
 		}
 
-	bcopy(cbc_iv,iv3a,sizeof(cbc_iv));
-	bcopy(cbc3_iv,iv3b,sizeof(cbc_iv));
+	memcpy(iv3a,cbc_iv,sizeof(cbc_iv));
+	memcpy(iv3b,cbc3_iv,sizeof(cbc_iv));
 	des_3cbc_encrypt((C_Block *)cbc_out,(C_Block *)cbc_in,
 		i,ks,ks2,(C_Block *)iv3a,
 		(C_Block *)iv3b,DES_DECRYPT);
-	if (bcmp(cbc_in,cbc_data,strlen(cbc_data)+1) != 0)
+	if (memcmp(cbc_in,cbc_data,strlen(cbc_data)+1) != 0)
 		{
 		printf("des_3cbc_encrypt decrypt error\n");
 		err=1;
@@ -370,18 +379,18 @@ main()
 		printf("Key error %d\n",j);
 		err=1;
 		}
-	bzero(cbc_out,40);
-	bzero(cbc_in,40);
+	memset(cbc_out,0,40);
+	memset(cbc_in,0,40);
 	des_pcbc_encrypt((C_Block *)cbc_data,(C_Block *)cbc_out,
 		(long)strlen(cbc_data)+1,ks,(C_Block *)cbc_iv,DES_ENCRYPT);
-	if (bcmp(cbc_out,pcbc_ok,32) != 0)
+	if (memcmp(cbc_out,pcbc_ok,32) != 0)
 		{
 		printf("pcbc_encrypt encrypt error\n");
 		err=1;
 		}
 	des_pcbc_encrypt((C_Block *)cbc_out,(C_Block *)cbc_in,
 		(long)strlen(cbc_data)+1,ks,(C_Block *)cbc_iv,DES_DECRYPT);
-	if (bcmp(cbc_in,cbc_data,32) != 0)
+	if (memcmp(cbc_in,cbc_data,32) != 0)
 		{
 		printf("pcbc_encrypt decrypt error\n");
 		err=1;
@@ -402,21 +411,21 @@ main()
 	printf("cfb64 ");
 	err+=cfb64_test(64,cfb_cipher64);
 
-	bcopy(cfb_iv,cfb_tmp,sizeof(cfb_iv));
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	for (i=0; i<sizeof(plain); i++)
 		des_cfb_encrypt(&(plain[i]),&(cfb_buf1[i]),
 			8,(long)1,ks,(C_Block *)cfb_tmp,DES_ENCRYPT);
-	if (bcmp(cfb_cipher8,cfb_buf1,sizeof(plain)) != 0)
+	if (memcmp(cfb_cipher8,cfb_buf1,sizeof(plain)) != 0)
 		{
 		printf("cfb_encrypt small encrypt error\n");
 		err=1;
 		}
 
-	bcopy(cfb_iv,cfb_tmp,sizeof(cfb_iv));
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	for (i=0; i<sizeof(plain); i++)
 		des_cfb_encrypt(&(cfb_buf1[i]),&(cfb_buf2[i]),
 			8,(long)1,ks,(C_Block *)cfb_tmp,DES_DECRYPT);
-	if (bcmp(plain,cfb_buf2,sizeof(plain)) != 0)
+	if (memcmp(plain,cfb_buf2,sizeof(plain)) != 0)
 		{
 		printf("cfb_encrypt small decrypt error\n");
 		err=1;
@@ -425,18 +434,18 @@ main()
 
 	printf("Doing ofb\n");
 	key_sched((C_Block *)ofb_key,ks);
-	bcopy(ofb_iv,ofb_tmp,sizeof(ofb_iv));
+	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	des_ofb_encrypt(plain,ofb_buf1,64,(long)sizeof(plain)/8,ks,
 		(C_Block *)ofb_tmp);
-	if (bcmp(ofb_cipher,ofb_buf1,sizeof(ofb_buf1)) != 0)
+	if (memcmp(ofb_cipher,ofb_buf1,sizeof(ofb_buf1)) != 0)
 		{
 		printf("ofb_encrypt encrypt error\n");
 		err=1;
 		}
-	bcopy(ofb_iv,ofb_tmp,sizeof(ofb_iv));
+	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	des_ofb_encrypt(ofb_buf1,ofb_buf2,64,(long)sizeof(ofb_buf1)/8,ks,
 		(C_Block *)ofb_tmp);
-	if (bcmp(plain,ofb_buf2,sizeof(ofb_buf2)) != 0)
+	if (memcmp(plain,ofb_buf2,sizeof(ofb_buf2)) != 0)
 		{
 		printf("ofb_encrypt decrypt error\n");
 		err=1;
@@ -444,25 +453,25 @@ main()
 
 	printf("Doing ofb64\n");
 	key_sched((C_Block *)ofb_key,ks);
-	bcopy(ofb_iv,ofb_tmp,sizeof(ofb_iv));
-	bzero(ofb_buf1,sizeof(ofb_buf1));
-	bzero(ofb_buf2,sizeof(ofb_buf1));
+	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
+	memset(ofb_buf1,0,sizeof(ofb_buf1));
+	memset(ofb_buf2,0,sizeof(ofb_buf1));
 	num=0;
 	for (i=0; i<sizeof(plain); i++)
 		{
 		des_ofb64_encrypt(&(plain[i]),&(ofb_buf1[i]),1,ks,
 			(C_Block *)ofb_tmp,&num);
 		}
-	if (bcmp(ofb_cipher,ofb_buf1,sizeof(ofb_buf1)) != 0)
+	if (memcmp(ofb_cipher,ofb_buf1,sizeof(ofb_buf1)) != 0)
 		{
 		printf("ofb64_encrypt encrypt error\n");
 		err=1;
 		}
-	bcopy(ofb_iv,ofb_tmp,sizeof(ofb_iv));
+	memcpy(ofb_tmp,ofb_iv,sizeof(ofb_iv));
 	num=0;
 	des_ofb64_encrypt(ofb_buf1,ofb_buf2,(long)sizeof(ofb_buf1),ks,
 		(C_Block *)ofb_tmp,&num);
-	if (bcmp(plain,ofb_buf2,sizeof(ofb_buf2)) != 0)
+	if (memcmp(plain,ofb_buf2,sizeof(ofb_buf2)) != 0)
 		{
 		printf("ofb64_encrypt decrypt error\n");
 		err=1;
@@ -478,7 +487,7 @@ main()
 			cs,cbc_cksum_ret);
 		err=1;
 		}
-	if (bcmp(cret,cbc_cksum_data,8) != 0)
+	if (memcmp(cret,cbc_cksum_data,8) != 0)
 		{
 		printf("bad cbc_cksum block returned\n");
 		err=1;
@@ -490,7 +499,7 @@ main()
 	for (i=0; i<4; i++)
 		{
 		lqret[i]=0;
-		bcopy(&(qret[i][0]),&(lqret[i]),4);
+		memcpy(&(lqret[i]),&(qret[i][0]),4);
 		}
 	{ /* Big-endian fix */
 	static unsigned long l=1;
@@ -571,7 +580,7 @@ main()
 	exit(err);
 	}
 
-char *pt(p)
+static char *pt(p)
 unsigned char *p;
 	{
 	static char bufs[10][20];
@@ -591,28 +600,28 @@ unsigned char *p;
 	return(ret);
 	}
 	
-int cfb_test(bits,cfb_cipher)
+static int cfb_test(bits, cfb_cipher)
 int bits;
-char *cfb_cipher;
+unsigned char *cfb_cipher;
 	{
 	des_key_schedule ks;
 	int i,err=0;
 
 	key_sched((C_Block *)cfb_key,ks);
-	bcopy(cfb_iv,cfb_tmp,sizeof(cfb_iv));
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	des_cfb_encrypt(plain,cfb_buf1,bits,(long)sizeof(plain),ks,
 		(C_Block *)cfb_tmp,DES_ENCRYPT);
-	if (bcmp(cfb_cipher,cfb_buf1,sizeof(plain)) != 0)
+	if (memcmp(cfb_cipher,cfb_buf1,sizeof(plain)) != 0)
 		{
 		err=1;
 		printf("cfb_encrypt encrypt error\n");
 		for (i=0; i<24; i+=8)
 			printf("%s\n",pt(&(cfb_buf1[i])));
 		}
-	bcopy(cfb_iv,cfb_tmp,sizeof(cfb_iv));
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	des_cfb_encrypt(cfb_buf1,cfb_buf2,bits,(long)sizeof(plain),ks,
 		(C_Block *)cfb_tmp,DES_DECRYPT);
-	if (bcmp(plain,cfb_buf2,sizeof(plain)) != 0)
+	if (memcmp(plain,cfb_buf2,sizeof(plain)) != 0)
 		{
 		err=1;
 		printf("cfb_encrypt decrypt error\n");
@@ -622,36 +631,36 @@ char *cfb_cipher;
 	return(err);
 	}
 
-int cfb64_test(bits,cfb_cipher)
+static int cfb64_test(bits, cfb_cipher)
 int bits;
-char *cfb_cipher;
+unsigned char *cfb_cipher;
 	{
 	des_key_schedule ks;
 	int err=0,i,n;
 
 	key_sched((C_Block *)cfb_key,ks);
-	bcopy(cfb_iv,cfb_tmp,sizeof(cfb_iv));
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	n=0;
 	des_cfb64_encrypt(plain,cfb_buf1,(long)12,ks,
 		(C_Block *)cfb_tmp,&n,DES_ENCRYPT);
 	des_cfb64_encrypt(&(plain[12]),&(cfb_buf1[12]),
 		(long)sizeof(plain)-12,ks,
 		(C_Block *)cfb_tmp,&n,DES_ENCRYPT);
-	if (bcmp(cfb_cipher,cfb_buf1,sizeof(plain)) != 0)
+	if (memcmp(cfb_cipher,cfb_buf1,sizeof(plain)) != 0)
 		{
 		err=1;
 		printf("cfb_encrypt encrypt error\n");
 		for (i=0; i<24; i+=8)
 			printf("%s\n",pt(&(cfb_buf1[i])));
 		}
-	bcopy(cfb_iv,cfb_tmp,sizeof(cfb_iv));
+	memcpy(cfb_tmp,cfb_iv,sizeof(cfb_iv));
 	n=0;
 	des_cfb64_encrypt(cfb_buf1,cfb_buf2,(long)17,ks,
 		(C_Block *)cfb_tmp,&n,DES_DECRYPT);
 	des_cfb64_encrypt(&(cfb_buf1[17]),&(cfb_buf2[17]),
 		(long)sizeof(plain)-17,ks,
 		(C_Block *)cfb_tmp,&n,DES_DECRYPT);
-	if (bcmp(plain,cfb_buf2,sizeof(plain)) != 0)
+	if (memcmp(plain,cfb_buf2,sizeof(plain)) != 0)
 		{
 		err=1;
 		printf("cfb_encrypt decrypt error\n");
