@@ -8,12 +8,14 @@
 
 #include "des_locl.h"
 
-int des_ede3_cbc_encrypt(input,output,length,ks1,ks2,ks3,ivec,encrypt)
-des_cblock *input;
-des_cblock *output;
-long length;
-des_key_schedule ks1,ks2,ks3;
-des_cblock *ivec;
+int des_ede3_cbc_encrypt(input, output, length, ks1, ks2, ks3, ivec, encrypt)
+des_cblock (*input);
+des_cblock (*output);
+long int length;
+struct des_ks_struct *ks1;
+struct des_ks_struct *ks2;
+struct des_ks_struct *ks3;
+des_cblock (*ivec);
 int encrypt;
 	{
 	register unsigned long tin0,tin1;
