@@ -335,12 +335,17 @@ static const unsigned long skb[8][64]={
 
 static const char shifts2[16]={0,0,1,1,1,1,1,1,0,1,1,1,1,1,1,0};
 
+#ifdef PROTO
+static int body(unsigned long *out0, unsigned long *out1, des_key_schedule ks, unsigned long Eswap0, unsigned long Eswap1);
+static int des_set_key(des_cblock (*key), struct des_ks_struct *schedule);
+#else
 static int body();
 static int des_set_key();
+#endif
 
-static int des_set_key(key,schedule)
-des_cblock *key;
-des_key_schedule schedule;
+static int des_set_key(key, schedule)
+des_cblock (*key);
+struct des_ks_struct *schedule;
 	{
 	register unsigned long c,d,t,s;
 	register unsigned char *in;
@@ -473,10 +478,14 @@ static unsigned const char cov_2char[64]={
 #ifdef PERL5
 char *des_crypt(buf,salt)
 #else
-char *crypt(buf,salt)
-#endif
+char *crypt(buf, salt)
 char *buf;
 char *salt;
+          
+           
+#endif
+     
+      
 	{
 	unsigned int i,j,x,y;
 	unsigned long Eswap0=0,Eswap1=0;
@@ -511,7 +520,7 @@ char *salt;
 		key[i]=0;
 
 	des_set_key((des_cblock *)(key),ks);
-	body(&out[0],&out[1],ks,Eswap0,Eswap1);
+	body(&(out[0]),&(out[1]),ks,Eswap0,Eswap1);
 
 	ll=out[0]; l2c(ll,b);
 	ll=out[1]; l2c(ll,b);
@@ -538,10 +547,12 @@ char *salt;
 	return((char *)buff);
 	}
 
-static int body(out0,out1,ks,Eswap0,Eswap1)
-unsigned long *out0,*out1;
-des_key_schedule *ks;
-unsigned long Eswap0,Eswap1;
+static int body(out0, out1, ks, Eswap0, Eswap1)
+unsigned long *out0;
+unsigned long *out1;
+des_key_schedule ks;
+unsigned long Eswap0;
+unsigned long Eswap1;
 	{
 	register unsigned long l,r,t,u;
 #ifdef ALT_ECB
