@@ -7,16 +7,21 @@
  */
 
 #include <stdio.h>
-/*#include "bn.h" */
-#include "PEM.h"
+#include "crypto.h"
 #include "X509.h"
+#include "PEM.h"
 
 #define DEFBITS	512
-static void cb();
 
-main(argc,argv)
+#ifdef PROTO
+static void cb(int p, int n);
+#else
+static void cb();
+#endif
+
+main(argc, argv)
 int argc;
-char *argv[];
+char **argv;
 	{
 	RSA *rsa;
 	int num=DEFBITS;
@@ -35,10 +40,10 @@ char *argv[];
 		fprintf(stderr,"usage: genrsa [-enc] [numbits]\n");
 		exit(1);
 		}
-	fprintf(stderr,"Generating RSA private key, %d bits long modulus\n",
+	fprintf(stderr,"Generating RSA private key, %d bit long modulus\n",
 		num);
 	RSA_set_generate_prime_callback(cb);
-	rsa=RSA_generate_key(num);
+	rsa=RSA_generate_key(num,1);
 	if (rsa == NULL)
 		{
 		fprintf(stderr,"RSA_generate_key:%s\n",
@@ -55,8 +60,9 @@ char *argv[];
 	return(0); /* shut lint up */
 	}
 
-static void cb(p,n)
-int p,n;
+static void cb(p, n)
+int p;
+int n;
 	{
 	char *str;
 
