@@ -6,7 +6,7 @@
  * See the COPYRIGHT file in the SSLeay distribution for more details.
  */
 
-static char *version="\0lhash part of SSLeay v 0.4.2 06/06/95";
+static char *version="\0lhash part of SSLeay v 0.4.3 15/06/95";
 
 /* Code for dynamic hash table routines
  * Author - Eric Young v 1.7
@@ -31,20 +31,24 @@ static char *version="\0lhash part of SSLeay v 0.4.2 06/06/95";
  */
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 #include "lhash.h"
 
 #define MIN_NODES	16
 #define UP_LOAD		(2*LH_LOAD_MULT) /* load times 256  (default 2) */
 #define DOWN_LOAD	(LH_LOAD_MULT)   /* load times 256  (default 1) */
 
-char *malloc(),*realloc();
-void free();
-
+#ifdef PROTO
+static void expand(LHASH *lh);
+static void contract(LHASH *lh);
+static LHASH_NODE **getrn(LHASH *lh, char *data, unsigned long *rhash);
+#else
 static void expand();
 static void contract();
 static LHASH_NODE **getrn();
+#endif
 
-LHASH *lh_new(h,c)
+LHASH *lh_new(h, c)
 unsigned long (*h)();
 int (*c)();
 	{
@@ -95,7 +99,7 @@ LHASH *lh;
 	free((char *)lh);
 	}
 
-char *lh_insert(lh,data)
+char *lh_insert(lh, data)
 LHASH *lh;
 char *data;
 	{
@@ -131,7 +135,7 @@ char *data;
 	return(ret);
 	}
 
-char *lh_delete(lh,data)
+char *lh_delete(lh, data)
 LHASH *lh;
 char *data;
 	{
@@ -163,7 +167,7 @@ char *data;
 	return(ret);
 	}
 
-char *lh_retrieve(lh,data)
+char *lh_retrieve(lh, data)
 LHASH *lh;
 char *data;
 	{
@@ -186,11 +190,11 @@ char *data;
 	return(ret);
 	}
 
-void lh_doall(lh,func)
+void lh_doall(lh, func)
 LHASH *lh;
 void (*func)();
 	{
-	int i;
+	unsigned int i;
 	LHASH_NODE *a,*n;
 
 	for (i=0; i<lh->num_nodes; i++)
@@ -211,8 +215,8 @@ static void expand(lh)
 LHASH *lh;
 	{
 	LHASH_NODE **n,**n1,**n2,*np;
-	int p,nni,i,j;
-	unsigned long hash;
+	int p,i,j;
+	unsigned long hash,nni;
 
 	lh->num_nodes++;
 	lh->num_expands++;
@@ -302,7 +306,7 @@ LHASH *lh;
 		}
 	}
 
-static LHASH_NODE **getrn(lh,data,rhash)
+static LHASH_NODE **getrn(lh, data, rhash)
 LHASH *lh;
 char *data;
 unsigned long *rhash;
@@ -339,7 +343,7 @@ unsigned long *rhash;
 	return(ret);
 	}
 
-void lh_stats(lh,out)
+void lh_stats(lh, out)
 LHASH *lh;
 FILE *out;
 	{
@@ -368,12 +372,12 @@ FILE *out;
 #endif
 	}
 
-void lh_node_stats(lh,out)
+void lh_node_stats(lh, out)
 LHASH *lh;
 FILE *out;
 	{
 	LHASH_NODE *n;
-	int i,num;
+	unsigned long i,num;
 
 	for (i=0; i<lh->num_nodes; i++)
 		{
@@ -383,13 +387,13 @@ FILE *out;
 		}
 	}
 
-void lh_node_usage_stats(lh,out)
+void lh_node_usage_stats(lh, out)
 LHASH *lh;
 FILE *out;
 	{
 	LHASH_NODE *n;
-	int i,num;
-	int total=0,n_used=0;
+	unsigned long i,num;
+	unsigned long total=0,n_used=0;
 
 	for (i=0; i<lh->num_nodes; i++)
 		{
