@@ -52,6 +52,18 @@ typedef struct lhash_st
 
 #define LH_LOAD_MULT	256
 
+#ifdef PROTO
+LHASH *lh_new(unsigned long (*h) (/* ??? */), int (*c) (/* ??? */));
+void lh_free(LHASH *lh);
+char *lh_insert(LHASH *lh, char *data);
+char *lh_delete(LHASH *lh, char *data);
+char *lh_retrieve(LHASH *lh, char *data);
+void lh_stats(LHASH *lh, FILE *out);
+void lh_node_stats(LHASH *lh, FILE *out);
+void lh_node_usage_stats(LHASH *lh, FILE *out);
+void lh_doall(LHASH *lh, void (*func) (/* ??? */));
+unsigned long lh_strhash(char *c);
+#else
 LHASH *lh_new();
 void lh_free();
 char *lh_insert();
@@ -62,5 +74,6 @@ void lh_node_stats();
 void lh_node_usage_stats();
 void lh_doall();
 unsigned long lh_strhash();
+#endif
 
 #endif
