@@ -11,15 +11,23 @@
 
 #define BUFSIZE	1024*16
 
+#ifdef PROTO
+void do_fp(FILE *f);
+void pt(unsigned char *md);
+int read(int, void *, unsigned int);
+void exit(int);
+void perror(const char *);
+#else
 void do_fp();
 void pt();
 int read();
 void exit();
 void perror();
+#endif
 
-main(argc,argv)
+main(argc, argv)
 int argc;
-char *argv[];
+char **argv;
 	{
 	int i,err=0;
 	FILE *IN;
