@@ -20,9 +20,16 @@ typedef struct MD2state_st
 	unsigned int state[MD2_BLOCK];
 	} MD2_CTX;
 
+#ifdef PROTO
+void MD2Init(MD2_CTX *c);
+void MD2Update(MD2_CTX *c, register unsigned char *data, unsigned long len);
+void MD2Final(unsigned char *md, MD2_CTX *c);
+unsigned char *MD2(unsigned long n, unsigned char *d, unsigned char *md);
+#else
 void MD2Init();
 void MD2Update();
 void MD2Final();
 unsigned char *MD2();
+#endif
 
 #endif
