@@ -9,7 +9,7 @@
 #include <stdio.h>
 #include "md2.h"
 
-static char *version="\0MD2 part of SSLeay v 0.4.2 06/06/95";
+static char *version="\0MD2 part of SSLeay v 0.4.3 15/06/95";
 
 /* Implemented from RFC1319 The MD2 Message-Digest Algorithm
  */
@@ -17,7 +17,11 @@ static char *version="\0MD2 part of SSLeay v 0.4.2 06/06/95";
 #define UCHAR	unsigned char
 #define UOBJ	unsigned int
 
+#ifdef PROTO
+static void do_block(MD2_CTX *c, unsigned char *d);
+#else
 static void do_block();
+#endif
 
 /* The magic S table - I have converted it to hex since it is
  * basicaly just a random byte string. */
@@ -56,7 +60,7 @@ static UOBJ S[256]={
 	0xDB, 0x99, 0x8D, 0x33, 0x9F, 0x11, 0x83, 0x14,
 	};
 
-unsigned char *MD2(n,d,md)
+unsigned char *MD2(n, d, md)
 unsigned long n;
 unsigned char *d;
 unsigned char *md;
@@ -86,12 +90,12 @@ MD2_CTX *c;
 		p1[i]=p2[i]=p3[i]=0;
 	}
 
-void MD2Update(c,data,len)
+void MD2Update(c, data, len)
 MD2_CTX *c;
-register UCHAR *data;
+register unsigned char *data;
 unsigned long len;
 	{
-	register int i;
+	register unsigned int i;
 	register UCHAR *p;
 
 	p=c->data;
@@ -127,7 +131,7 @@ unsigned long len;
 	c->num=len;
 	}
 
-static void do_block(c,d)
+static void do_block(c, d)
 MD2_CTX *c;
 unsigned char *d;
 	{
@@ -159,7 +163,7 @@ unsigned char *d;
 		state[i]=0;
 	}
 
-void MD2Final(md,c)
+void MD2Final(md, c)
 unsigned char *md;
 MD2_CTX *c;
 	{
