@@ -7,6 +7,8 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include "md2.h"
 
 char *test[]={
@@ -30,10 +32,11 @@ char *ret[]={
 	"d5976f79d83d3a0dc9806c3c66f3efd8",
 	};
 
+#ifdef PROTO
+static char *pt(unsigned char *md);
+#else
 static char *pt();
-unsigned int strlen();
-int strcmp();
-void exit();
+#endif
 
 main()
 	{
