@@ -7,18 +7,24 @@
  */
 
 #include <stdio.h>
+#include <stdlib.h>
 #include "md5.h"
 
 #define BUFSIZE	1024*16
 
+#ifdef PROTO
+void do_fp(FILE *f);
+void pt(unsigned char *md);
+int read(int, void *, unsigned int);
+#else
 void do_fp();
 void pt();
 int read();
-void exit();
+#endif
 
-main(argc,argv)
+main(argc, argv)
 int argc;
-char *argv[];
+char **argv;
 	{
 	int i,err=0;
 	FILE *IN;
