@@ -23,11 +23,20 @@ typedef struct MD5state_st
 	int num;
 	} MD5_CTX;
 
+#ifdef PROTO
+void MD5Init(MD5_CTX *c);
+void MD5Update(MD5_CTX *c, unsigned char *data, unsigned long len);
+void MD5Final(unsigned char *md, MD5_CTX *c);
+unsigned char *MD5(unsigned long n, unsigned char *d, unsigned char *md);
+void MD5_rand(int num, unsigned char *buf);
+void MD5_rand_seed(int num, unsigned char *buf);
+#else
 void MD5Init();
 void MD5Update();
 void MD5Final();
 unsigned char *MD5();
 void MD5_rand();
 void MD5_rand_seed();
+#endif
 
 #endif
