@@ -9,7 +9,7 @@
 #include <stdio.h>
 #include "md5_locl.h"
 
-static char *version="\0MD5 part of SSLeay v 0.4.2 06/06/95";
+static char *version="\0MD5 part of SSLeay v 0.4.3 15/06/95";
 
 /* Implemented from RFC1321 The MD5 Message-Digest Algorithm
  */
@@ -18,9 +18,13 @@ static const ULONG init_data[4]={
 	0x67452301L,0xefcdab89L,0x98badcfeL,0x10325476L
 	};
 
+#ifdef PROTO
+static void do_block(MD5_CTX *c, register unsigned char *p);
+#else
 static void do_block();
+#endif
 
-unsigned char *MD5(n,d,md)
+unsigned char *MD5(n, d, md)
 unsigned long n;
 unsigned char *d;
 unsigned char *md;
@@ -47,12 +51,12 @@ MD5_CTX *c;
 	c->num=0;
 	}
 
-void MD5Update(c,data,len)
+void MD5Update(c, data, len)
 MD5_CTX *c;
-register UCHAR *data;
+register unsigned char *data;
 unsigned long len;
 	{
-	register int i;
+	register unsigned int i;
 	register UCHAR *p;
 	ULONG l;
 
@@ -97,9 +101,9 @@ unsigned long len;
 	c->num=len;
 	}
 
-static void do_block(c,p)
+static void do_block(c, p)
 MD5_CTX *c;
-register UCHAR *p;
+register unsigned char *p;
 	{
 	register ULONG A,B,C,D;
 	ULONG *xp;
@@ -194,7 +198,7 @@ register UCHAR *p;
 	c->D+=D&0xffffffff;
 	}
 
-void MD5Final(md,c)
+void MD5Final(md, c)
 unsigned char *md;
 MD5_CTX *c;
 	{
