@@ -24,10 +24,6 @@
 #define const
 #endif
 
-#ifdef __STDC__
-#define PROTO
-#endif
-
 #define c2l(c,l)	(l = ((unsigned long)(*((c)++)))     , \
 			 l|=(((unsigned long)(*((c)++)))<< 8), \
 			 l|=(((unsigned long)(*((c)++)))<<16), \
