@@ -7,6 +7,8 @@
  */
 
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
 #include "md5.h"
 
 char *test[]={
@@ -30,10 +32,11 @@ char *ret[]={
 	"57edf4a22be3c955ac49da2e2107b67a",
 	};
 
+#ifdef PROTO
+static char *pt(unsigned char *md);
+#else
 static char *pt();
-unsigned int strlen();
-int strcmp();
-void exit();
+#endif
 
 main()
 	{
@@ -46,8 +49,8 @@ main()
 	i=1;
 	while (*P != NULL)
 		{
-		p=pt(MD5((unsigned long)strlen(*P),*P,NULL));
-		if (strcmp(p,*R) != 0)
+		p=pt(MD5((unsigned long)strlen((char *)*P),*P,NULL));
+		if (strcmp(p,(char *)*R) != 0)
 			{
 			printf("error calculating MD5 on '%s'\n",*P);
 			printf("got %s instead of %s\n",p,*R);
