@@ -19,7 +19,12 @@ typedef struct rc4_key_st
 	RC4_INT data[256];
 	} RC4_KEY;
 
+#ifdef PROTO
+void RC4_set_key(RC4_KEY *key, int len, register unsigned char *data);
+void RC4(RC4_KEY *key, unsigned int len, unsigned char *indata, unsigned char *outdata);
+#else
 void RC4_set_key();
 void RC4();
+#endif
 
 #endif
