@@ -8,7 +8,7 @@
 
 #include "rc4.h"
 
-static char *version="\0RC4 part of SSLeay v 0.4.2 06/06/95";
+static char *version="\0RC4 part of SSLeay v 0.4.3 15/06/95";
 
 /* RC4 as implemented from a posting from
  * Newsgroups: sci.crypt
@@ -17,7 +17,7 @@ static char *version="\0RC4 part of SSLeay v 0.4.2 06/06/95";
  * Message-ID: <sternCvKL4B.Hyy@netcom.com>
  */
 
-void RC4_set_key(key,len,data)
+void RC4_set_key(key, len, data)
 RC4_KEY *key;
 int len;
 register unsigned char *data;
@@ -41,10 +41,11 @@ register unsigned char *data;
 		}       
 	}
     
-void RC4(key,len,indata,outdata)
+void RC4(key, len, indata, outdata)
 RC4_KEY *key;
-int len;
-unsigned char *indata,*outdata;
+unsigned int len;
+unsigned char *indata;
+unsigned char *outdata;
 	{
         register RC4_INT *d,tmp;
         register unsigned int x,y;
