@@ -18,62 +18,62 @@
 #include "ssl_rsa.h"
 #include "ssl_null.h"
 
-static char *version="\0SSLeay v 0.4.2 06/06/95";
+static char *version="\0SSLeay v 0.4.3 15/06/95";
 
 CIPHER ssl_ciphers[]={
 /* RC4_128_WITH_MD5 */
-{	1,SSL_TXT_RC4_128_WITH_MD5,
+	{	1,SSL_TXT_RC4_128_WITH_MD5,
 	ssl_enc_rc4_init,ssl_enc_rc4,ssl_compute_md5_mac,
 	16,16,1,0,SSL_CK_RC4_128_WITH_MD5,0},
 
 /* RC4_128_EXPORT40_WITH_MD5 */
-{	1,SSL_TXT_RC4_128_EXPORT40_WITH_MD5,
+	{	1,SSL_TXT_RC4_128_EXPORT40_WITH_MD5,
 	ssl_enc_rc4_init,ssl_enc_rc4,ssl_compute_md5_mac,
 	16,16,1,0,
 	SSL_CK_RC4_128_EXPORT40_WITH_MD5,40},
 
 /* RC2_128_CBC_WITH_MD5 */
-{	0,SSL_TXT_RC2_128_CBC_WITH_MD5,
+	{	0,SSL_TXT_RC2_128_CBC_WITH_MD5,
 	NULL,NULL,NULL,
 	0,0,0,0 ,SSL_CK_RC2_128_CBC_WITH_MD5,0},
 
 /* RC2_128_CBC_EXPORT40_WITH_MD5 */
-{	0,SSL_TXT_RC2_128_CBC_EXPORT40_WITH_MD5,
+	{	0,SSL_TXT_RC2_128_CBC_EXPORT40_WITH_MD5,
 	NULL,NULL,NULL,
 	0,0,0,0,
 	SSL_CK_RC2_128_CBC_EXPORT40_WITH_MD5,40},
 
 /* IDEA_128_CBC_WITH_MD5 */
-{	1,SSL_TXT_IDEA_128_CBC_WITH_MD5,
+	{	1,SSL_TXT_IDEA_128_CBC_WITH_MD5,
 	ssl_enc_idea_cbc_init,ssl_enc_idea_cbc,ssl_compute_md5_mac,
 	16,16,8,8,
 	SSL_CK_IDEA_128_CBC_WITH_MD5,0},
 
 /* DES_64_CBC_WITH_MD5 */
-{	1,SSL_TXT_DES_64_CBC_WITH_MD5,
+	{	1,SSL_TXT_DES_64_CBC_WITH_MD5,
 	ssl_enc_des_cbc_init,ssl_enc_des_cbc,ssl_compute_md5_mac,
 	8,16,8,8,
 	SSL_CK_DES_64_CBC_WITH_MD5,0},
 
 /* DES_192_EDE3_CBC_WITH_MD5 */
-{	1,SSL_TXT_DES_192_EDE3_CBC_WITH_MD5,
+	{	1,SSL_TXT_DES_192_EDE3_CBC_WITH_MD5,
 	ssl_enc_des_ede3_cbc_init,ssl_enc_des_ede3_cbc,ssl_compute_md5_mac,
 	24,16,8,8,
 	SSL_CK_DES_192_EDE3_CBC_WITH_MD5,0},
 
 /* NULL_64_WITH_MD5 */
-{	0,SSL_TXT_NULL_64_WITH_MD5,
+	{	0,SSL_TXT_NULL_64_WITH_MD5,
 	ssl_enc_null_init,ssl_enc_null,ssl_compute_md5_mac,
 	8,16,0,0,
 	SSL_CK_NULL_64_WITH_MD5,0},
 
 /* DES_64_CFB64_WITH_NULL */
-{	1,SSL_TXT_DES_64_CFB64_WITH_NULL,
+	{	1,SSL_TXT_DES_64_CFB64_WITH_NULL,
 	ssl_enc_des_cfb_init,ssl_enc_des_cfb,ssl_compute_null_mac,
 	8,0,1,8,
 	SSL_CK_DES_64_CFB64_WITH_NULL,0},
 
-{ 	-1,"",NULL,NULL,NULL,0,0,0,0,0,0,0,0},
+	{ 	-1,"",NULL,NULL,NULL,0,0,0,0,0,0,0,0},
 	};
 
 static int num_pref_cipher=8;
@@ -187,25 +187,7 @@ SSL *s;
 	free((char *)s);
 	}
 
-#ifdef undef
-void ssl_set_cipher_kind(s,type,null,key_bits)
-SSL *s;
-int type,null,key_bits;
-	{
-	if ((type > NUM_CIPHERS) || (!ssl_ciphers[type].valid))
-		{
-		/* BAD ERROR */
-		SSL_TRACE(SSL_ERR,"bad cipher choice\n");
-		abort();
-		}
-	s->conn->cipher=&(ssl_ciphers[type]);
-	if (s->crypt_state != NULL)
-		free(s->crypt_state);
-	s->crypt_state=NULL;
-	}
-#endif
-
-void ssl_print_bytes(f,n,b)
+void ssl_print_bytes(f, n, b)
 FILE *f;
 int n;
 char *b;
@@ -214,15 +196,21 @@ char *b;
 	static char *h="0123456789abcdef";
 
 	/* NULL means don't trace/log */
-        if (f == NULL)
+   if (f == NULL)
 	    return;
 
+	fflush(f);
+	ssl_ddt_dump_fd(fileno(f),b,n);
+
+#if 0
 	for (i=0; i<n; i++)
 		{
 		fputc(h[(b[i]>>4)&0x0f],f);
 		fputc(h[(b[i]   )&0x0f],f);
 		fputc(' ',f);
 		}
+#endif
+
 	}
 
 void ssl_return_error(s)
@@ -230,14 +218,14 @@ SSL *s;
 	{
 	static unsigned char buf[1]={SSL_MT_ERROR};
 
-	SSL_write(s,buf,1);
+	SSL_write(s,(char *)buf,1);
 #ifdef ABORT_DEBUG
 	abort(1);
 #endif
 	}
 
 
-void SSL_set_fd(s,fd)
+void SSL_set_fd(s, fd)
 SSL *s;
 int fd;
 	{
@@ -250,7 +238,7 @@ SSL *s;
 	return(s->fd);
 	}
 
-int SSL_set_pref_cipher(s,str)
+int SSL_set_pref_cipher(s, str)
 SSL *s;
 char *str;
 	{
@@ -293,7 +281,7 @@ err:
 	return(0);
 	}
 
-char *SSL_get_pref_cipher(s,n)
+char *SSL_get_pref_cipher(s, n)
 SSL *s;
 int n;
 	{
@@ -314,8 +302,9 @@ SSL *s;
 	return(NULL);
 	}
 
-int SSL_copy_session_id(to,from)
-SSL *to,*from;
+int SSL_copy_session_id(to, from)
+SSL *to;
+SSL *from;
 	{
 	if (from->conn == NULL) return(0);
 	to->conn=from->conn;
@@ -323,7 +312,7 @@ SSL *to,*from;
 	return(1);
 	}
 
-void SSL_set_verify(s,mode,callback)
+void SSL_set_verify(s, mode, callback)
 SSL *s;
 int mode;
 int (*callback)();
@@ -332,7 +321,7 @@ int (*callback)();
 	s->verify_callback=callback;
 	}
 
-void SSL_set_read_ahead(s,yes)
+void SSL_set_read_ahead(s, yes)
 SSL *s;
 int yes;
 	{
@@ -351,7 +340,7 @@ SSL *s;
 	return(s->rbuf_left);
 	}
 
-int SSL_set_timeout(s,t)
+int SSL_set_timeout(s, t)
 SSL *s;
 int t;
 	{
