@@ -1,4 +1,4 @@
-/* client.c */
+/* ssl_client.c */
 /* Copyright (C) 1995 Eric Young (eay@mincom.oz.au).
  * All rights reserved.
  * Copyright remains Eric Young's, and as such any Copyright notices in
@@ -16,11 +16,10 @@
 #include "net.h"
 /*#include "X509.h"*/
 /*#include "ssl.h"*/
-#include "der.h"
-#include "bn.h"
-#include "PEM.h"
 #include "X509.h"
+#include "PEM.h"
 #include "ssl_locl.h"
+#include "ssl_apps.h"
 
 /*#define SSL_HOST_NAME	"www.netscape.com" /**/
 /*#define SSL_HOST_NAME	"193.118.187.102" /**/
@@ -33,9 +32,6 @@
 int verify_depth=0;
 int verify_error=VERIFY_OK;
 
-int verify_callback();
-void set_cert_stuff();
-
 void usage()
 	{
 	fprintf(stderr,"usage: client args\n");
@@ -54,9 +50,9 @@ void usage()
 	fprintf(stderr,"                 CFB-DES-NULL\n");
 	}
 
-main(argc,argv)
+main(argc, argv)
 int argc;
-char *argv[];
+char **argv;
 	{
 	SSL *con,*con2;
 	int s,i,width;
@@ -143,8 +139,8 @@ bad:
 		exit(1);
 		}
 
-        SSL_debug("client.log");
-	if (init_client(host,&s,SERVICE,port) == 0)
+   SSL_debug("client.log");
+	if (init_client(&s,host,port) == 0)
 		{ perror("conecting"); exit(1); }
 	fprintf(stderr,"CONNECTED\n");
 
@@ -183,7 +179,7 @@ bad:
 		SSL_write(con,"bye\n",4);
 		close(s); 
 
-		if (init_client(host,&s,SERVICE,port) == 0)
+		if (init_client(&s,host,port) == 0)
 			{ perror("conecting"); exit(1); }
 
 		fprintf(stderr,"drop the connection and reconnect with the same session id\n");
@@ -228,16 +224,16 @@ bad:
 	int i=0;
 
 	c= &(con->conn->ciphers[0]);
-	printf("Ciphers common between both SSL endpoints:\n\t");
+	printf("Ciphers common between both SSL endpoints:\n");
 	while (c[i] != NULL)
 		{
-		printf("%-12s%s",c[i]->name,((i+1) % 3)?" ":"\n\t");
+		printf("%-12s%s",c[i]->name,((i+1) % 3)?" ":"\n");
 		i++;
 		}
 	if ((i) % 3) printf("\n");
 	}
 
-	printf("CIPHER is %s\n",SSL_get_cipher(con));
+	printf("Cipher is %s\n",SSL_get_cipher(con));
 
 	for (;;)
 		{
@@ -270,141 +266,4 @@ bad:
 	return(0);
 	}
 
-int init_client(server,sock,service,port)
-char *server;
-int *sock;
-char *service;
-int port;
-	{
-	struct servent ser;
-	struct servent *serv;
-	struct sockaddr_in them;
-	struct hostent *host;
-	struct protoent *prot;
-	u_long ip_them;
-	int s,i;
 
-	if ((serv=getservbyname(service,PROTO)) == NULL)
-		{
-		serv= &ser;
-		ser.s_port=htons(port);
-		}
-
-	host=gethostbyname(server);
-	if (host == NULL)
-		{
-		int a,b,c,d;
-
-		if (sscanf(server,"%d.%d.%d.%d",&a,&b,&c,&d) == 4)
-			ip_them=(a<<24)|(b<<16)|(c<<8)|d;
-		else
-			{
-			fprintf(stderr,"unable to get %s's ip address\n",
-				server);
-			return(0);
-			}
-		}
-	else
-		memcpy(&ip_them,host->h_addr_list[0],sizeof(ip_them));
-	memset((char *)&them,0,sizeof(them));
-	them.sin_family=AF_INET;
-	them.sin_port=serv->s_port;
-	them.sin_addr.s_addr=ip_them;
-
-	prot=getprotobyname("tcp");
-	if (prot == NULL)
-		{
-		fprintf(stderr,"unable to find tcp protocol number");
-		return(0);
-		}
-	s=socket(AF_INET,SOCK_STREAM,prot->p_proto);
-	if (s == -1) { fprintf(stderr,"socket:%m"); return(0); }
-
-/*	ling.l_onoff=1;
-	ling.l_linger=0;
-	i=setsockopt(s,SOL_SOCKET,SO_LINGER,(char *)&ling,sizeof(ling));
-	if (i < 0) { fprintf(stderr,"linger:%m"); exit(0); } /**/
-	i=0;
-	i=setsockopt(s,SOL_SOCKET,SO_KEEPALIVE,(char *)&i,sizeof(i));
-	if (i < 0) { fprintf(stderr,"keepalive:%m"); exit(0); }
-
-	if (connect(s,(struct sockaddr *)&them,sizeof(them)) == -1)
-		{
-		close(s);
-		perror("connect");
-		return(0);
-		}
-	*sock=s;
-	return(1);
-	}
-
-/* duplicated in server.c and client.c */
-int verify_callback(ok,xs,xi,depth,error)
-int ok;
-char *xs,*xi; /* should be X509 * but we can just have them as char *. */
-int depth,error;
-	{
-	char *s;
-
-	s=(char *)X509_oneline_X509_NAME(X509_get_subject_name(xs));
-	if (s == NULL)
-		{
-		fprintf(stderr,"error:%s\n",X509_error_string(X509_errno));
-		return(0);
-		}
-	fprintf(stderr,"depth=%d %s\n",depth,s);
-	free(s);
-	if (error == VERIFY_ERR_UNABLE_TO_GET_ISSUER)
-		{
-		s=(char *)X509_oneline_X509_NAME(X509_get_issuer_name(xs));
-		if (s == NULL)
-			{
-			fprintf(stderr,"verify error:%s\n",
-				X509_error_string(X509_errno));
-			return(0);
-			}
-		fprintf(stderr,"issuer= %s\n",s);
-		free(s);
-		}
-	if (!ok)
-		{
-		fprintf(stderr,"verify error:num=%d:%s\n",error,
-			X509_verify_error_string(error));
-		if (verify_depth <= depth)
-			{
-			ok=1;
-			verify_error=VERIFY_OK;
-			}
-		else
-			{
-			ok=0;
-			verify_error=error;
-			}
-		}
-	fprintf(stderr,"verify return:%d\n",ok);
-	return(ok);
-	}
-
-void set_cert_stuff(con,cert_file,key_file)
-SSL *con;
-char *cert_file,*key_file;
-	{
-	if (cert_file != NULL)
-		{
-		if (SSL_use_certificate_file(con,cert_file,
-			X509_FILETYPE_PEM) <= 0)
-			{
-			fprintf(stderr,"unable to set certificate file\n");
-			fprintf(stderr,"%s\n",SSL_error_string(SSL_errno));
-			exit(1);
-			}
-		if (key_file == NULL) key_file=cert_file;
-		if (SSL_use_RSAPrivateKey_file(con,key_file,
-			X509_FILETYPE_PEM) <= 0)
-			{
-			fprintf(stderr,"unable to set public key file\n");
-			fprintf(stderr,"%s\n",SSL_error_string(SSL_errno));
-			exit(1);
-			}
-		}
-	}
