@@ -9,10 +9,10 @@
 #include <stdio.h>
 #include "des.h"
 #include "md5.h"
-#include "ssl_des.h"
 #include "ssl_locl.h"
+#include "ssl_des.h"
 
-int ssl_enc_des_cbc_init(s,client)
+int ssl_enc_des_cbc_init(s, client)
 SSL *s;
 int client;
 	{
@@ -35,7 +35,7 @@ int client;
 
 	MD5Init(&md5s);
 	MD5Update(&md5s,s->conn->master_key,s->conn->master_key_length);
-	MD5Update(&md5s,"0",1);
+	MD5Update(&md5s,(unsigned char *)"0",1);
 	MD5Update(&md5s,s->challenge,s->challenge_length);
 	MD5Update(&md5s,s->conn_id,s->conn_id_length);
 	MD5Final(md5d,&md5s);
@@ -109,7 +109,7 @@ SSL *s;
 #endif
 	}
 
-int ssl_enc_des_ede3_cbc_init(s,client)
+int ssl_enc_des_ede3_cbc_init(s, client)
 SSL *s;
 int client;
 	{
@@ -133,29 +133,29 @@ int client;
 
 	MD5Init(&md5s);
 	MD5Update(&md5s,s->conn->master_key,s->conn->master_key_length);
-	MD5Update(&md5s,"0",1);
+	MD5Update(&md5s,(unsigned char *)"0",1);
 	MD5Update(&md5s,s->challenge,s->challenge_length);
 	MD5Update(&md5s,s->conn_id,s->conn_id_length);
 	MD5Final(md5d0,&md5s);
 
 	MD5Init(&md5s);
 	MD5Update(&md5s,s->conn->master_key,s->conn->master_key_length);
-	MD5Update(&md5s,"1",1);
+	MD5Update(&md5s,(unsigned char *)"1",1);
 	MD5Update(&md5s,s->challenge,s->challenge_length);
 	MD5Update(&md5s,s->conn_id,s->conn_id_length);
 	MD5Final(md5d1,&md5s);
 
 	MD5Init(&md5s);
 	MD5Update(&md5s,s->conn->master_key,s->conn->master_key_length);
-	MD5Update(&md5s,"2",1);
+	MD5Update(&md5s,(unsigned char *)"2",1);
 	MD5Update(&md5s,s->challenge,s->challenge_length);
 	MD5Update(&md5s,s->conn_id,s->conn_id_length);
 	MD5Final(md5d2,&md5s);
 
-	bcopy(md5d0,&(s->conn->key_material[0]),MD5_DIGEST_LENGTH);
-	bcopy(md5d1,&(s->conn->key_material[MD5_DIGEST_LENGTH]),
+	memcpy(&(s->conn->key_material[0]),md5d0,MD5_DIGEST_LENGTH);
+	memcpy(&(s->conn->key_material[MD5_DIGEST_LENGTH]),md5d1,
 		MD5_DIGEST_LENGTH);
-	bcopy(md5d2,&(s->conn->key_material[MD5_DIGEST_LENGTH*2]),
+	memcpy(&(s->conn->key_material[MD5_DIGEST_LENGTH*2]),md5d2,
 		MD5_DIGEST_LENGTH);
 
 	des_set_odd_parity((C_Block *)&(md5d0[0]));
@@ -187,12 +187,12 @@ int client;
 		s->write_key= &(s->conn->key_material[0]);
 		s->read_key= &(s->conn->key_material[24]);
 		}
-	bcopy(s->conn->key_arg,ds->read_iv,DES_KEY_SZ);
-	bcopy(s->conn->key_arg,ds->write_iv,DES_KEY_SZ);
+	memcpy(ds->read_iv,s->conn->key_arg,DES_KEY_SZ);
+	memcpy(ds->write_iv,s->conn->key_arg,DES_KEY_SZ);
 
-	bzero(md5d0,MD5_DIGEST_LENGTH);
-	bzero(md5d1,MD5_DIGEST_LENGTH);
-	bzero(md5d2,MD5_DIGEST_LENGTH);
+	memset(md5d0,0,MD5_DIGEST_LENGTH);
+	memset(md5d1,0,MD5_DIGEST_LENGTH);
+	memset(md5d2,0,MD5_DIGEST_LENGTH);
 	return(1);
 err:
 	SSL_errno=SSL_ERRCODE(SSL_F_SSL_ENC_DES_EDE3_CBC_INIT,
@@ -246,7 +246,7 @@ SSL *s;
 #endif
 	}
 
-int ssl_enc_des_cfb_init(s,client)
+int ssl_enc_des_cfb_init(s, client)
 SSL *s;
 int client;
 	{
@@ -274,7 +274,7 @@ int client;
 
 	/* duplicate because we don't want cleared parity in recorded
 	 * version */
-	bcopy(md5d,c->key_material,MD5_DIGEST_LENGTH);
+	memcpy(c->key_material,md5d,MD5_DIGEST_LENGTH);
 
 	des_set_odd_parity((C_Block *)&(md5d[0]));
 	des_set_odd_parity((C_Block *)&(md5d[8]));
@@ -295,9 +295,9 @@ int client;
 		}
 	ds->readn=0;
 	ds->writen=0;
-	bcopy(s->conn->key_arg,ds->read_iv,DES_KEY_SZ);
-	bcopy(s->conn->key_arg,ds->write_iv,DES_KEY_SZ);
-	bzero(md5d,MD5_DIGEST_LENGTH);
+	memcpy(ds->read_iv,s->conn->key_arg,DES_KEY_SZ);
+	memcpy(ds->write_iv,s->conn->key_arg,DES_KEY_SZ);
+	memset(md5d,0,MD5_DIGEST_LENGTH);
 	return(1);
 err:
 	SSL_errno=SSL_ERRCODE(SSL_F_SSL_ENC_DES_EDE3_CBC_INIT,
@@ -330,15 +330,15 @@ SSL *s;
 #endif
 	if (s->send)
 		{
-		des_cfb64_encrypt((des_cblock *)s->mac_data,
-			(des_cblock *)s->mac_data,(long)l,ds->write_ks,
+		des_cfb64_encrypt((unsigned char *)s->mac_data,
+			(unsigned char *)s->mac_data,(long)l,ds->write_ks,
 			(des_cblock *)ds->write_iv,&ds->writen,
 			DES_ENCRYPT);
 		}
 	else
 		{
-		des_cfb64_encrypt((des_cblock *)s->mac_data,
-			(des_cblock *)s->mac_data,(long)l,ds->read_ks,
+		des_cfb64_encrypt((unsigned char *)s->mac_data,
+			(unsigned char *)s->mac_data,(long)l,ds->read_ks,
 			(des_cblock *)ds->read_iv,&ds->readn,
 			DES_DECRYPT);
 		}
