@@ -36,11 +36,18 @@ typedef struct des_cfb_state_st
 	C_Block write_iv;
 	} DES_CFB_STATE;
 
+#ifdef PROTO
+int ssl_enc_des_cbc_init(SSL *s, int client);
+void ssl_enc_des_cbc(SSL *s);
+int ssl_enc_des_ede3_cbc_init(SSL *s, int client);
+void ssl_enc_des_ede3_cbc(SSL *s);
+int ssl_enc_des_cfb_init(SSL *s, int client);
+void ssl_enc_des_cfb(SSL *s);
+#else
 int ssl_enc_des_cbc_init();
 void ssl_enc_des_cbc();
-
 int ssl_enc_des_ede3_cbc_init();
 void ssl_enc_des_ede3_cbc();
-
 int ssl_enc_des_cfb_init();
 void ssl_enc_des_cfb();
+#endif
