@@ -7,10 +7,10 @@
  */
 
 #include <stdio.h>
+#include "der.h"
 #include "X509.h"
 #include "PEM.h"
-#include "der.h"
-#include "ssl.h"
+#include "ssl_locl.h"
 #include "ssl_err.h"
 
 /* NOTE: these error strings are a direct mapping of the #define to a
