@@ -14,5 +14,10 @@ typedef struct idea_state_st
 	unsigned char write_iv[8];
 	} IDEA_CBC_STATE;
 
+#ifdef PROTO
+int ssl_enc_idea_cbc_init(SSL *s, int client);
+void ssl_enc_idea_cbc(SSL *s);
+#else
 int ssl_enc_idea_cbc_init();
 void ssl_enc_idea_cbc();
+#endif
