@@ -8,15 +8,11 @@
 
 #ifndef HEADER_SSL_LOCL_H
 #define HEADER_SSL_LOCL_H
-#include "der.h"
-#include "bn.h"
-#include "X509.h"
-
+#include <stdlib.h>
+#include <time.h>
 #include <string.h>
-#define bcopy(b1,b2,len) memcpy(b2, b1, (size_t)(len))
-#define bzero(b,len) memset(b, 0, (size_t)(len))
-#define bcmp(b1,b2,len) memcmp(b1, b2, (size_t)(len))
-#define index(s1,char) strchr(s1,char)
+#include <unistd.h>
+#include "X509.h"
 
 #if !defined(_LIBC) || defined(NOCONST)
 #define const
@@ -179,14 +175,38 @@ extern FILE *SSL_LOG;
 extern FILE *SSL_ERR;
 */
 
-/* ERIC - this is visible even with PKT_DEBUG off! */
 #ifdef PKT_DEBUG
 void ssl_debug();
 #endif
 
+#ifdef PROTO
+CERT *ssl_cert_new(void);
+void ssl_clear(SSL *s);
+void ssl_conn_free(CONN *c);
+void ssl_cert_free(CERT *c);
+RSA *ssl_rsa_extract_public_key(X509 *x);
+void ssl_return_error(SSL *s);
+int ssl_set_certificate(SSL *s, int type, int len, unsigned char *data);
+int ssl_set_cert_type(CERT *c, int type);
+int ssl_new_conn(SSL *s, int session);
+int ssl_get_prev_conn(SSL *s, int len, unsigned char *session);
+void ssl_add_hash_conn(CONN *c);
+int ssl_rsa_public_decrypt(CERT *c, int len, unsigned char *from, unsigned char *to);
+#else
 CERT *ssl_cert_new();
+void ssl_clear();
 void ssl_conn_free();
+void ssl_cert_free();
 RSA *ssl_rsa_extract_public_key();
-RSA *ssl_ssl_set_certificate();
+void ssl_return_error();
+int ssl_set_certificate();
+int ssl_set_cert_type();
+int ssl_new_conn();
+int ssl_get_prev_conn();
+void ssl_add_hash_conn();
+int ssl_rsa_public_decrypt();
 #endif
 
+#endif
+
+extern int errno;
