@@ -8,4 +8,8 @@
 
 #define MD5_MAC_SIZE    16
 
+#ifdef PROTO
+void ssl_compute_md5_mac(SSL *s, unsigned char *md);
+#else
 void ssl_compute_md5_mac();
+#endif
