@@ -7,10 +7,10 @@
  */
 
 #include <stdio.h>
-#include "ssl_null.h"
 #include "ssl_locl.h"
+#include "ssl_null.h"
 
-int ssl_enc_null_init(s,client)
+int ssl_enc_null_init(s, client)
 SSL *s;
 int client;
 	{
@@ -32,8 +32,8 @@ int client;
 		s->read_key= &(ns->b[0]);
 		s->write_key= &(ns->a[0]);
 		}
-	bcopy(s->conn->master_key,&(ns->a[0]),8);
-	bcopy(s->conn->master_key,&(ns->b[0]),8);
+	memcpy(&(ns->a[0]),s->conn->master_key,8);
+	memcpy(&(ns->b[0]),s->conn->master_key,8);
 	return(1);
 err:
 	SSL_errno=SSL_ERRCODE(SSL_F_SSL_ENC_NULL_INIT,SSL_R_OUT_OF_MEMORY);
@@ -57,7 +57,7 @@ SSL *s;
 		*(p++)^=k[i%8];
 */	}
 
-void ssl_compute_null_mac(s,md)
+void ssl_compute_null_mac(s, md)
 SSL *s;
 char *md;
 	{
