@@ -12,7 +12,12 @@ typedef struct null_state_st
 	unsigned char b[8];
 	} NULL_STATE;
 
+#ifdef PROTO
+int ssl_enc_null_init(SSL *s, int client);
+void ssl_enc_null(SSL *s);
+void ssl_compute_null_mac(SSL *s, char *md);
+#else
 int ssl_enc_null_init();
 void ssl_enc_null();
-
 void ssl_compute_null_mac();
+#endif
