@@ -12,5 +12,10 @@ typedef struct rc4_state_st
 	RC4_KEY rc4_write_ks;
 	} RC4_STATE;
 
+#ifdef PROTO
+int ssl_enc_rc4_init(SSL *s, int client);
+void ssl_enc_rc4(SSL *s);
+#else
 int ssl_enc_rc4_init();
 void ssl_enc_rc4();
+#endif
