@@ -7,10 +7,11 @@
  */
 
 #include <stdio.h>
+#include "crypto.h"
 #include "der.h"
 #include "bn.h"
-#include "PEM.h"
 #include "X509.h"
+#include "PEM.h"
 
 #define	POSTFIX	".serial"
 
@@ -45,13 +46,25 @@ char *usage[]={
 NULL
 };
 
+#ifdef PROTO
+static int callb(int ok, X509 *xs, X509 *xi, int depth, int error);
+static RSA *load_key(char *file, int format);
+static X509 *load_cert(char *file, int format);
+static int str2fmt (char *s);
+static int sign (X509 *x, RSA *rsa);
+static int certify (char *CAfile, X509 *x, X509 *xca, RSA *rsa, int create);
+#else
 static int callb();
-RSA *load_key();
-X509 *load_cert();
+static RSA *load_key();
+static X509 *load_cert();
+static int str2fmt ();
+static int sign ();
+static int certify ();
+#endif
 
-main(argc,argv)
+main(argc, argv)
 int argc;
-char *argv[];
+char **argv;
 	{
 	X509 *x,*xca;
 	RSA *rsa,*CArsa;
@@ -271,7 +284,7 @@ end:
 	return(0);
 	}
 
-int str2fmt(s)
+static int str2fmt(s)
 char *s;
 	{
 	if 	((*s == 'D') || (*s == 'd'))
@@ -284,16 +297,17 @@ char *s;
 		return(FORMAT_UNDEF);
 	}
 
-int certify(CAfile,x,xca,rsa,create)
+static int certify(CAfile, x, xca, rsa, create)
 char *CAfile;
-X509 *x,*xca;
+X509 *x;
+X509 *xca;
 RSA *rsa;
 int create;
 	{
 	FILE *io;
 	char *buf,buf2[1024];
 	BIGNUM *serial;
-	DER_BIT_STRING *bs;
+	DER_BIT_STRING *bs,bs2;
 
 	buf=(char *)malloc(bn_num_bytes(rsa->n)*2+
 		strlen(CAfile)+strlen(POSTFIX)+1);
@@ -314,7 +328,7 @@ int create;
 		if (!create)
 			{
 			perror(buf);
-			exit(0);
+			exit(1);
 			}
 		else
 			bn_zero(serial);
@@ -342,8 +356,8 @@ int create;
 
 	if (!bn_add_word(serial,1))
 		{ fprintf(stderr,"add_word failure\n"); return(0); }
-	bs->data=(unsigned char *)buf2;
-	bs->length=bn_bn2bin(serial,bs->data);
+	bs2.data=(unsigned char *)buf2;
+	bs2.length=bn_bn2bin(serial,bs2.data);
 
 	io=fopen(buf,"w");
 	if (io == NULL)
@@ -352,7 +366,7 @@ int create;
 		perror(buf);
 		exit(1);
 		}
-	i2f_DER_BIT_STRING(io,bs);
+	i2f_DER_BIT_STRING(io,&bs2);
 	fclose(io);
 	
 	if (!X509_add_cert(x)) return(0);
@@ -370,7 +384,7 @@ int create;
 	if (x->cert_info->validity->notBefore == NULL)
 		{
 		fprintf(stderr,"out of mem\n");
-		exit(0);
+		exit(1);
 		}
 
 	X509_gmtime(x->cert_info->validity->notBefore,0);
@@ -383,24 +397,27 @@ int create;
 	return(1);
 	}
 
-static int callb(ok,xs,xi,depth,error)
+static int callb(ok, xs, xi, depth, error)
 int ok;
-X509 *xs,*xi;
-int depth,error;
+X509 *xs;
+X509 *xi;
+int depth;
+int error;
 	{
 	/* it is ok to use a self signed certificate */
 	if ((!ok) && (error == VERIFY_ERR_DEPTH_ZERO_SELF_SIGNED_CERT))
-		return(ok);
-	if ((!ok) || (depth > 0))
-		{
+		return(1);
+
+	/* BAD we should have gotten an error :-) */
+	if (ok)
+		printf("error with certificate to be certified - should be self signed\n");
+	else
 		printf("error with certificate - error %d at depth %d\n%s\n",
 			error,depth,X509_verify_error_string(error));
-			return(ok);
-		}
-	return(ok);
+	return(0);
 	}
 
-RSA *load_key(file,format)
+static RSA *load_key(file, format)
 char *file;
 int format;
 	{
@@ -432,7 +449,7 @@ int format;
 	return(rsa);
 	}
 
-X509 *load_cert(file,format)
+static X509 *load_cert(file, format)
 char *file;
 int format;
 	{
@@ -475,7 +492,7 @@ int format;
 	return(x);
 	}
 
-int sign(x,rsa)
+static int sign(x, rsa)
 X509 *x;
 RSA *rsa;
 	{
